@@ -13,8 +13,6 @@
    You should have received a copy of the GNU General Public License along with
    TALER; see the file COPYING.  If not, see <http://www.gnu.org/licenses/>
  */
-
-
 #include "platform.h"
 #include <gnunet/gnunet_util_lib.h>
 #include <gnunet/gnunet_json_lib.h>
@@ -26,34 +24,33 @@
 #include "taler-auditor-httpd.h"
 #include "taler-auditor-httpd_refreshes-hanging-get.h"
 
+
 /**
  * Add refreshes-hanging to the list.
  *
  * @param[in,out] cls a `json_t *` array to extend
- * @param serial_id location of the @a dc in the database
  * @param dc struct of inconsistencies
  * @return #GNUNET_OK to continue to iterate, #GNUNET_SYSERR to stop iterating
  */
 static enum GNUNET_GenericReturnValue
 process_refreshes_hanging (
   void *cls,
-  uint64_t serial_id,
   const struct TALER_AUDITORDB_RefreshesHanging *dc)
 {
   json_t *list = cls;
   json_t *obj;
 
   obj = GNUNET_JSON_PACK (
-
-    TALER_JSON_pack_amount ("amount", &dc->amount),
-    GNUNET_JSON_pack_data_auto ("coin_pub", &dc->coin_pub)
-
+    TALER_JSON_pack_amount ("amount",
+                            &dc->amount),
+    GNUNET_JSON_pack_uint64 ("serial_id",
+                             dc->row_id),
+    GNUNET_JSON_pack_uint64 ("problem_row",
+                             dc->problem_row_id)
     );
   GNUNET_break (0 ==
                 json_array_append_new (list,
                                        obj));
-
-
   return GNUNET_OK;
 }
 
@@ -69,6 +66,9 @@ TAH_REFRESHES_HANGING_handler_get (
 {
   json_t *ja;
   enum GNUNET_DB_QueryStatus qs;
+  int64_t limit = -20;
+  uint64_t offset;
+  bool return_suppressed = false;
 
   (void) rh;
   (void) connection_cls;
@@ -83,34 +83,31 @@ TAH_REFRESHES_HANGING_handler_get (
                                        TALER_EC_GENERIC_DB_SETUP_FAILED,
                                        NULL);
   }
-  ja = json_array ();
-  GNUNET_break (NULL != ja);
-
-  int64_t limit = -20;
-  uint64_t offset;
-
   TALER_MHD_parse_request_snumber (connection,
                                    "limit",
                                    &limit);
-
   if (limit < 0)
     offset = INT64_MAX;
   else
     offset = 0;
-
   TALER_MHD_parse_request_number (connection,
                                   "offset",
                                   &offset);
-
-  bool return_suppressed = false;
-  const char *ret_s = MHD_lookup_connection_value (connection,
-                                                   MHD_GET_ARGUMENT_KIND,
-                                                   "return_suppressed");
-  if (ret_s != NULL && strcmp (ret_s, "true") == 0)
   {
-    return_suppressed = true;
-  }
+    const char *ret_s
+      = MHD_lookup_connection_value (connection,
+                                     MHD_GET_ARGUMENT_KIND,
+                                     "return_suppressed");
 
+    if ( (NULL != ret_s) &&
+         (0 == strcmp (ret_s,
+                       "true")) )
+    {
+      return_suppressed = true;
+    }
+  }
+  ja = json_array ();
+  GNUNET_break (NULL != ja);
   qs = TAH_plugin->get_refreshes_hanging (
     TAH_plugin->cls,
     limit,
@@ -118,7 +115,6 @@ TAH_REFRESHES_HANGING_handler_get (
     return_suppressed,
     &process_refreshes_hanging,
     ja);
-
   if (0 > qs)
   {
     GNUNET_break (GNUNET_DB_STATUS_HARD_ERROR == qs);
