@@ -463,7 +463,7 @@ load_config (const char *cfgfile)
 {
   struct GNUNET_CONFIGURATION_Handle *cfg;
 
-  cfg = GNUNET_CONFIGURATION_create ();
+  cfg = GNUNET_CONFIGURATION_create (TALER_AUDITOR_project_data ());
   GNUNET_log (GNUNET_ERROR_TYPE_INFO,
               "Loading config file: %s\n",
               cfgfile);
@@ -523,13 +523,15 @@ static void
 setup (struct GNUNET_CONFIGURATION_Handle *src_cfg,
        struct GNUNET_CONFIGURATION_Handle *dst_cfg)
 {
-  src = TALER_EXCHANGEDB_plugin_load (src_cfg);
+  src = TALER_EXCHANGEDB_plugin_load (src_cfg,
+                                      false);
   if (NULL == src)
   {
     global_ret = EXIT_NOTINSTALLED;
     return;
   }
-  dst = TALER_EXCHANGEDB_plugin_load (dst_cfg);
+  dst = TALER_EXCHANGEDB_plugin_load (dst_cfg,
+                                      false);
   if (NULL == dst)
   {
     global_ret = EXIT_NOTINSTALLED;
@@ -570,6 +572,7 @@ main (int argc,
     GNUNET_GETOPT_option_mandatory (
       option_cfgfile_dst (&dst_cfgfile)),
     GNUNET_GETOPT_option_help (
+      TALER_AUDITOR_project_data (),
       gettext_noop ("Make a safe copy of an exchange database")),
     GNUNET_GETOPT_option_uint (
       'b',
@@ -589,7 +592,6 @@ main (int argc,
     GNUNET_GETOPT_OPTION_END
   };
 
-  TALER_OS_init ();
   TALER_gcrypt_init (); /* must trigger initialization manually at this point! */
   {
     int ret;
