@@ -96,20 +96,18 @@ static enum GNUNET_DB_QueryStatus eqs;
  * in #TALER_ARL_edb.  Update the deposit confirmation context accordingly.
  *
  * @param cls our `struct DepositConfirmationContext`
- * @param serial_id row of the @a dc in the database
  * @param dc the deposit confirmation we know
  * @return #GNUNET_OK to continue to iterate, #GNUNET_SYSERR to stop iterating
  */
 static enum GNUNET_GenericReturnValue
 test_dc (void *cls,
-         uint64_t serial_id,
          const struct TALER_AUDITORDB_DepositConfirmation *dc)
 {
   bool missing = false;
   enum GNUNET_DB_QueryStatus qs;
 
   (void) cls;
-  TALER_ARL_USE_PP (deposit_confirmation_serial_id) = serial_id;
+  TALER_ARL_USE_PP (deposit_confirmation_serial_id) = dc->row_id;
   for (unsigned int i = 0; i < dc->num_coins; i++)
   {
     struct GNUNET_TIME_Timestamp exchange_timestamp;
@@ -123,7 +121,12 @@ test_dc (void *cls,
                                        dc->refund_deadline,
                                        &deposit_fee,
                                        &exchange_timestamp);
-    missing |= (0 == qs);
+    GNUNET_log (GNUNET_ERROR_TYPE_INFO,
+                "Status for deposit confirmation %llu-%u is %d\n",
+                (unsigned long long) dc->row_id,
+                i,
+                qs);
+    missing |= (GNUNET_DB_STATUS_SUCCESS_NO_RESULTS == qs);
     if (qs < 0)
     {
       GNUNET_break (0); /* DB error, complain */
@@ -131,16 +134,21 @@ test_dc (void *cls,
       return GNUNET_SYSERR;
     }
   }
-  qs = TALER_ARL_adb->delete_deposit_confirmation (TALER_ARL_adb->cls,
-                                                   serial_id);
-  if (qs < 0)
-  {
-    GNUNET_break (0); /* DB error, complain */
-    eqs = qs;
-    return GNUNET_SYSERR;
-  }
   if (! missing)
   {
+    GNUNET_log (GNUNET_ERROR_TYPE_INFO,
+                "Deleting matching deposit confirmation %llu\n",
+                (unsigned long long) dc->row_id);
+    qs = TALER_ARL_adb->delete_generic (
+      TALER_ARL_adb->cls,
+      TALER_AUDITORDB_DEPOSIT_CONFIRMATION,
+      dc->row_id);
+    if (qs < 0)
+    {
+      GNUNET_break (0); /* DB error, complain */
+      eqs = qs;
+      return GNUNET_SYSERR;
+    }
     GNUNET_log (GNUNET_ERROR_TYPE_DEBUG,
                 "Found deposit %s in exchange database\n",
                 GNUNET_h2s (&dc->h_contract_terms.hash));
@@ -394,15 +402,8 @@ main (int argc,
   };
   enum GNUNET_GenericReturnValue ret;
 
-  /* force linker to link against libtalerutil; if we do
-     not do this, the linker may "optimize" libtalerutil
-     away and skip #TALER_OS_init(), which we do need */
-  (void) TALER_project_data_default ();
-  if (GNUNET_OK !=
-      GNUNET_STRINGS_get_utf8_args (argc, argv,
-                                    &argc, &argv))
-    return EXIT_INVALIDARGUMENT;
   ret = GNUNET_PROGRAM_run (
+    TALER_AUDITOR_project_data (),
     argc,
     argv,
     "taler-helper-auditor-deposits",
@@ -411,7 +412,6 @@ main (int argc,
     options,
     &run,
     NULL);
-  GNUNET_free_nz ((void *) argv);
   if (GNUNET_SYSERR == ret)
     return EXIT_INVALIDARGUMENT;
   if (GNUNET_NO == ret)
