@@ -167,7 +167,7 @@ struct ReserveClosure
   /**
    * Target account where the money was sent.
    */
-  char *receiver_account;
+  struct TALER_FullPayto receiver_account;
 
   /**
    * Wire transfer subject used.
@@ -229,11 +229,6 @@ static TALER_ARL_DEF_AB (total_bad_amount_out_plus);
  */
 static TALER_ARL_DEF_AB (total_bad_amount_out_minus);
 
-/**
- * Total amount which the exchange did not transfer in time.
- */
-static TALER_ARL_DEF_AB (total_amount_lag);
-
 /**
  * Total amount of reserve closures which the exchange did not transfer in time.
  */
@@ -357,7 +352,7 @@ free_rc (void *cls,
                  GNUNET_CONTAINER_multihashmap_remove (reserve_closures,
                                                        key,
                                                        rc));
-  GNUNET_free (rc->receiver_account);
+  GNUNET_free (rc->receiver_account.full_payto);
   GNUNET_free (rc);
   return GNUNET_OK;
 }
@@ -449,9 +444,9 @@ check_pending_rc (void *cls,
 
   (void) cls;
   (void) key;
-  TALER_ARL_amount_add (&TALER_ARL_USE_AB (total_closure_amount_lag),
-                        &TALER_ARL_USE_AB (total_closure_amount_lag),
-                        &rc->amount);
+  GNUNET_log (GNUNET_ERROR_TYPE_INFO,
+              "Missing wire transfer for closed reserve with balance %s\n",
+              TALER_amount2s (&rc->amount));
   if (! TALER_amount_is_zero (&rc->amount))
   {
     struct TALER_AUDITORDB_ClosureLags cl = {
@@ -463,6 +458,8 @@ check_pending_rc (void *cls,
     };
     enum GNUNET_DB_QueryStatus qs;
 
+    /* FIXME: where do we *undo* this if the wire transfer is
+       found later? */
     qs = TALER_ARL_adb->insert_auditor_closure_lags (
       TALER_ARL_adb->cls,
       &cl);
@@ -472,10 +469,12 @@ check_pending_rc (void *cls,
       GNUNET_break (GNUNET_DB_STATUS_SOFT_ERROR == qs);
       return GNUNET_SYSERR;
     }
+    /* FIXME: where do we *undo* this if the wire transfer is
+       found later? */
+    TALER_ARL_amount_add (&TALER_ARL_USE_AB (total_closure_amount_lag),
+                          &TALER_ARL_USE_AB (total_closure_amount_lag),
+                          &rc->amount);
   }
-  TALER_ARL_USE_PP (wire_reserve_close_id)
-    = GNUNET_MIN (TALER_ARL_USE_PP (wire_reserve_close_id),
-                  rc->rowid);
   return GNUNET_OK;
 }
 
@@ -489,22 +488,25 @@ check_pending_rc (void *cls,
  * @param[out] key set to the key
  */
 static void
-hash_rc (const char *receiver_account,
+hash_rc (const struct TALER_FullPayto receiver_account,
          const struct TALER_WireTransferIdentifierRawP *wtid,
          struct GNUNET_HashCode *key)
 {
-  size_t slen = strlen (receiver_account);
+  struct TALER_NormalizedPayto npto
+    = TALER_payto_normalize (receiver_account);
+  size_t slen = strlen (npto.normalized_payto);
   char buf[sizeof (struct TALER_WireTransferIdentifierRawP) + slen];
 
   GNUNET_memcpy (buf,
                  wtid,
                  sizeof (*wtid));
   GNUNET_memcpy (&buf[sizeof (*wtid)],
-                 receiver_account,
+                 npto.normalized_payto,
                  slen);
   GNUNET_CRYPTO_hash (buf,
                       sizeof (buf),
                       key);
+  GNUNET_free (npto.normalized_payto);
 }
 
 
@@ -525,6 +527,9 @@ begin_transaction (void);
 static void
 commit (enum GNUNET_DB_QueryStatus qs)
 {
+  GNUNET_CONTAINER_multihashmap_iterate (reserve_closures,
+                                         &check_pending_rc,
+                                         NULL);
   GNUNET_log (GNUNET_ERROR_TYPE_INFO,
               "Transaction logic ended with status %d\n",
               qs);
@@ -535,7 +540,6 @@ commit (enum GNUNET_DB_QueryStatus qs)
     TALER_ARL_SET_AB (total_wire_out),
     TALER_ARL_SET_AB (total_bad_amount_out_plus),
     TALER_ARL_SET_AB (total_bad_amount_out_minus),
-    TALER_ARL_SET_AB (total_amount_lag),
     TALER_ARL_SET_AB (total_closure_amount_lag),
     TALER_ARL_SET_AB (wire_debit_duplicate_transfer_subject_total),
     TALER_ARL_SET_AB (total_wire_out),
@@ -548,7 +552,6 @@ commit (enum GNUNET_DB_QueryStatus qs)
     TALER_ARL_SET_AB (total_wire_out),
     TALER_ARL_SET_AB (total_bad_amount_out_plus),
     TALER_ARL_SET_AB (total_bad_amount_out_minus),
-    TALER_ARL_SET_AB (total_amount_lag),
     TALER_ARL_SET_AB (total_closure_amount_lag),
     TALER_ARL_SET_AB (wire_debit_duplicate_transfer_subject_total),
     TALER_ARL_SET_AB (total_wire_out),
@@ -588,9 +591,6 @@ commit (enum GNUNET_DB_QueryStatus qs)
                 (unsigned long long) wa->last_wire_out_serial_id,
                 wa->ai->section_name);
   }
-  GNUNET_CONTAINER_multihashmap_iterate (reserve_closures,
-                                         &check_pending_rc,
-                                         NULL);
   qs = TALER_ARL_adb->update_auditor_progress (
     TALER_ARL_adb->cls,
     TALER_ARL_SET_PP (wire_reserve_close_id),
@@ -724,8 +724,8 @@ check_rc_matches (void *cls,
 
   if ((0 == GNUNET_memcmp (&cmx->roi->details.wtid,
                            &rc->wtid)) &&
-      (0 == strcasecmp (rc->receiver_account,
-                        cmx->roi->details.credit_account_uri)) &&
+      (0 == TALER_full_payto_cmp (rc->receiver_account,
+                                  cmx->roi->details.credit_account_uri)) &&
       (0 == TALER_amount_cmp (&rc->amount,
                               &cmx->roi->details.amount)))
   {
@@ -792,7 +792,7 @@ check_reported_inconsistency (struct ReserveOutInfo *roi)
   char diag[MAX_DIAG_LEN];
   struct TALER_AUDITORDB_WireOutInconsistency woi = {
     .wire_out_row_id = roi->details.serial_id,
-    .destination_account = (char *) roi->details.credit_account_uri,
+    .destination_account = roi->details.credit_account_uri,
     .diagnostic = diag,
     .expected = roi->details.amount,
     .claimed = zero,
@@ -813,8 +813,11 @@ check_reported_inconsistency (struct ReserveOutInfo *roi)
   if (GNUNET_DB_STATUS_SUCCESS_NO_RESULTS == qs)
   {
     GNUNET_log (GNUNET_ERROR_TYPE_WARNING,
-                "Deletion of wire out inconsistency %llu failed: not reported missing!\n",
-                (unsigned long long) roi->details.serial_id);
+                "Deletion of wire out inconsistency %llu (%s, %s, %s) failed: not reported missing!\n",
+                (unsigned long long) roi->details.serial_id,
+                roi->details.credit_account_uri.full_payto,
+                diag,
+                TALER_amount2s (&roi->details.amount));
     return GNUNET_NO;
   }
   TALER_ARL_amount_subtract (&TALER_ARL_USE_AB (total_bad_amount_out_minus),
@@ -838,7 +841,7 @@ check_profit_drain (struct ReserveOutInfo *roi)
   enum GNUNET_DB_QueryStatus qs;
   uint64_t serial;
   char *account_section;
-  char *payto_uri;
+  struct TALER_FullPayto payto_uri;
   struct GNUNET_TIME_Timestamp request_timestamp;
   struct TALER_Amount amount;
   struct TALER_MasterSignatureP master_sig;
@@ -872,7 +875,7 @@ check_profit_drain (struct ReserveOutInfo *roi)
   GNUNET_log (GNUNET_ERROR_TYPE_INFO,
               "Profit drain of %s to %s found!\n",
               TALER_amount2s (&amount),
-              payto_uri);
+              payto_uri.full_payto);
   if (GNUNET_OK !=
       TALER_exchange_offline_profit_drain_verify (
         &roi->details.wtid,
@@ -885,15 +888,15 @@ check_profit_drain (struct ReserveOutInfo *roi)
   {
     struct TALER_AUDITORDB_RowInconsistency ri = {
       .row_id = roi->details.serial_id,
-      .row_table = "profit_drains",
-      .diagnostic = "invalid signature"
+      .row_table = (char *) "profit_drains",
+      .diagnostic = (char *) "invalid signature"
     };
 
     GNUNET_break (0);
     qs = TALER_ARL_adb->insert_row_inconsistency (
       TALER_ARL_adb->cls,
       &ri);
-    GNUNET_free (payto_uri);
+    GNUNET_free (payto_uri.full_payto);
     GNUNET_free (account_section);
     if (qs < 0)
     {
@@ -906,21 +909,18 @@ check_profit_drain (struct ReserveOutInfo *roi)
   GNUNET_free (account_section);
 
   {
-    char *np = TALER_payto_normalize (payto_uri);
-
     if (0 !=
-        strcasecmp (np,
-                    roi->details.credit_account_uri))
+        TALER_full_payto_normalize_and_cmp (payto_uri,
+                                            roi->details.credit_account_uri))
     {
       struct TALER_AUDITORDB_WireOutInconsistency woi = {
         .wire_out_row_id = serial,
-        .destination_account = (char *) roi->details.credit_account_uri,
-        .diagnostic = "profit drain wired to invalid account",
+        .destination_account = roi->details.credit_account_uri,
+        .diagnostic = (char *) "profit drain wired to invalid account",
         .expected = roi->details.amount,
         .claimed = zero,
       };
 
-      GNUNET_free (np);
       qs = TALER_ARL_adb->insert_wire_out_inconsistency (
         TALER_ARL_adb->cls,
         &woi);
@@ -928,26 +928,25 @@ check_profit_drain (struct ReserveOutInfo *roi)
       {
         global_qs = qs;
         GNUNET_break (GNUNET_DB_STATUS_SOFT_ERROR == qs);
-        GNUNET_free (payto_uri);
+        GNUNET_free (payto_uri.full_payto);
         return GNUNET_SYSERR;
       }
       TALER_ARL_amount_add (&TALER_ARL_USE_AB (total_bad_amount_out_plus),
                             &TALER_ARL_USE_AB (total_bad_amount_out_plus),
                             &amount);
-      GNUNET_free (payto_uri);
+      GNUNET_free (payto_uri.full_payto);
       return GNUNET_YES; /* justified, kind-of */
     }
-    GNUNET_free (np);
   }
-  GNUNET_free (payto_uri);
+  GNUNET_free (payto_uri.full_payto);
   if (0 !=
       TALER_amount_cmp (&amount,
                         &roi->details.amount))
   {
     struct TALER_AUDITORDB_WireOutInconsistency woi = {
       .wire_out_row_id = roi->details.serial_id,
-      .destination_account = (char *) roi->details.credit_account_uri,
-      .diagnostic = "incorrect amount drained to correct account",
+      .destination_account = roi->details.credit_account_uri,
+      .diagnostic = (char *) "incorrect amount drained to correct account",
       .expected = roi->details.amount,
       .claimed = amount,
     };
@@ -1007,6 +1006,10 @@ complain_out_not_found (void *cls,
   hash_rc (roi->details.credit_account_uri,
            &roi->details.wtid,
            &rkey);
+  GNUNET_log (GNUNET_ERROR_TYPE_INFO,
+              "Checking for reserve closure %s benefiting %s\n",
+              GNUNET_h2s (&rkey),
+              roi->details.credit_account_uri.full_payto);
   GNUNET_CONTAINER_multihashmap_get_multiple (reserve_closures,
                                               &rkey,
                                               &check_rc_matches,
@@ -1023,8 +1026,8 @@ complain_out_not_found (void *cls,
 
   {
     struct TALER_AUDITORDB_WireOutInconsistency woi = {
-      .destination_account = (char *) roi->details.credit_account_uri,
-      .diagnostic = "missing justification for outgoing wire transfer",
+      .destination_account = roi->details.credit_account_uri,
+      .diagnostic = (char *) "missing justification for outgoing wire transfer",
       .wire_out_row_id = roi->details.serial_id,
       .expected = zero,
       .claimed = roi->details.amount
@@ -1066,7 +1069,7 @@ wire_out_cb (
   uint64_t rowid,
   struct GNUNET_TIME_Timestamp date,
   const struct TALER_WireTransferIdentifierRawP *wtid,
-  const char *payto_uri,
+  const struct TALER_FullPayto payto_uri,
   const struct TALER_Amount *amount)
 {
   struct WireAccount *wa = cls;
@@ -1098,7 +1101,7 @@ wire_out_cb (
        May be cleared later by check_reported_inconsistency() */
     char diag[MAX_DIAG_LEN];
     struct TALER_AUDITORDB_WireOutInconsistency woi = {
-      .destination_account = (char *) payto_uri,
+      .destination_account = payto_uri,
       .diagnostic = diag,
       .wire_out_row_id = rowid,
       .expected = *amount,
@@ -1125,53 +1128,53 @@ wire_out_cb (
                           amount);
     return GNUNET_OK;
   }
+
+  if (0 != TALER_full_payto_normalize_and_cmp (payto_uri,
+                                               roi->details.credit_account_uri))
   {
-    char *np = TALER_payto_normalize (payto_uri);
+    /* Destination bank account is wrong in actual wire transfer, so
+       we should count the wire transfer as entirely spurious, and
+       additionally consider the justified wire transfer as missing. */
+    struct TALER_AUDITORDB_WireOutInconsistency woi = {
+      .wire_out_row_id = rowid,
+      .destination_account = payto_uri,
+      .diagnostic = (char *) "receiver account mismatch",
+      .expected = *amount,
+      .claimed = roi->details.amount,
+    };
+    enum GNUNET_DB_QueryStatus qs;
 
-    if (0 != strcasecmp (np,
-                         roi->details.credit_account_uri))
+    qs = TALER_ARL_adb->insert_wire_out_inconsistency (
+      TALER_ARL_adb->cls,
+      &woi);
+    if (qs < 0)
     {
-      /* Destination bank account is wrong in actual wire transfer, so
-         we should count the wire transfer as entirely spurious, and
-         additionally consider the justified wire transfer as missing. */
-      struct TALER_AUDITORDB_WireOutInconsistency woi = {
-        .wire_out_row_id = rowid,
-        .destination_account = (char *) payto_uri,
-        .diagnostic = "receiver account mismatch",
-        .expected = *amount,
-        .claimed = zero,
-      };
-      enum GNUNET_DB_QueryStatus qs;
-
-      GNUNET_free (np);
-      qs = TALER_ARL_adb->insert_wire_out_inconsistency (
-        TALER_ARL_adb->cls,
-        &woi);
-      if (qs < 0)
-      {
-        global_qs = qs;
-        GNUNET_break (GNUNET_DB_STATUS_SOFT_ERROR == qs);
-        return GNUNET_SYSERR;
-      }
-      TALER_ARL_amount_add (&TALER_ARL_USE_AB (total_bad_amount_out_plus),
-                            &TALER_ARL_USE_AB (total_bad_amount_out_plus),
-                            &roi->details.amount);
-      TALER_ARL_amount_add (&TALER_ARL_USE_AB (total_bad_amount_out_minus),
-                            &TALER_ARL_USE_AB (total_bad_amount_out_minus),
-                            amount);
-      return GNUNET_OK;
+      global_qs = qs;
+      GNUNET_break (GNUNET_DB_STATUS_SOFT_ERROR == qs);
+      return GNUNET_SYSERR;
     }
-    GNUNET_free (np);
+    TALER_ARL_amount_add (&TALER_ARL_USE_AB (total_bad_amount_out_plus),
+                          &TALER_ARL_USE_AB (total_bad_amount_out_plus),
+                          &roi->details.amount);
+    TALER_ARL_amount_add (&TALER_ARL_USE_AB (total_bad_amount_out_minus),
+                          &TALER_ARL_USE_AB (total_bad_amount_out_minus),
+                          amount);
+    GNUNET_assert (GNUNET_OK ==
+                   free_roi (NULL,
+                             &key,
+                             roi));
+    return GNUNET_OK;
   }
+
   if (0 != TALER_amount_cmp (&roi->details.amount,
                              amount))
   {
     struct TALER_AUDITORDB_WireOutInconsistency woi = {
-      .destination_account = (char *) payto_uri,
-      .diagnostic = "wire amount does not match",
+      .destination_account = payto_uri,
+      .diagnostic = (char *) "wire amount does not match",
       .wire_out_row_id = rowid,
       .expected = *amount,
-      .claimed = zero,
+      .claimed = roi->details.amount,
     };
     enum GNUNET_DB_QueryStatus qs;
 
@@ -1209,6 +1212,10 @@ wire_out_cb (
                             &TALER_ARL_USE_AB (total_bad_amount_out_plus),
                             &delta);
     }
+    GNUNET_assert (GNUNET_OK ==
+                   free_roi (NULL,
+                             &key,
+                             roi));
     return GNUNET_OK;
   }
 
@@ -1363,7 +1370,6 @@ history_debit_cb (
     {
       const struct TALER_BANK_DebitDetails *dd
         = &dhr->details.ok.details[i];
-      char *np = TALER_payto_normalize (dd->credit_account_uri);
 
       GNUNET_log (GNUNET_ERROR_TYPE_INFO,
                   "Analyzing bank DEBIT #%llu at %s of %s with WTID %s\n",
@@ -1372,19 +1378,18 @@ history_debit_cb (
                   TALER_amount2s (&dd->amount),
                   TALER_B2S (&dd->wtid));
       wa->wire_off_out = dd->serial_id + 1;
-      slen = strlen (np) + 1;
+      slen = strlen (dd->credit_account_uri.full_payto) + 1;
       roi = GNUNET_malloc (sizeof (struct ReserveOutInfo)
                            + slen);
       GNUNET_CRYPTO_hash (&dd->wtid,
                           sizeof (dd->wtid),
                           &roi->subject_hash);
       roi->details = *dd;
-      roi->details.credit_account_uri
-        = (const char *) &roi[1];
+      roi->details.credit_account_uri.full_payto
+        = (char *) &roi[1];
       GNUNET_memcpy (&roi[1],
-                     np,
+                     dd->credit_account_uri.full_payto,
                      slen);
-      GNUNET_free (np);
       if (GNUNET_OK !=
           GNUNET_CONTAINER_multihashmap_put (out_map,
                                              &roi->subject_hash,
@@ -1394,7 +1399,7 @@ history_debit_cb (
         struct TALER_AUDITORDB_WireFormatInconsistency wfi = {
           .amount = dd->amount,
           .wire_offset = dd->serial_id,
-          .diagnostic = "duplicate outgoing wire transfer subject"
+          .diagnostic = (char *) "duplicate outgoing wire transfer subject"
         };
         enum GNUNET_DB_QueryStatus qs;
 
@@ -1506,7 +1511,7 @@ reserve_closed_cb (
   const struct TALER_Amount *amount_with_fee,
   const struct TALER_Amount *closing_fee,
   const struct TALER_ReservePublicKeyP *reserve_pub,
-  const char *receiver_account,
+  const struct TALER_FullPayto receiver_account,
   const struct TALER_WireTransferIdentifierRawP *wtid,
   uint64_t close_request_row)
 {
@@ -1515,6 +1520,8 @@ reserve_closed_cb (
 
   (void) cls;
   (void) close_request_row;
+  GNUNET_assert (TALER_ARL_USE_PP (wire_reserve_close_id) <= rowid);
+  TALER_ARL_USE_PP (wire_reserve_close_id) = rowid + 1;
   rc = GNUNET_new (struct ReserveClosure);
   if (TALER_ARL_SR_INVALID_NEGATIVE ==
       TALER_ARL_amount_subtract_neg (&rc->amount,
@@ -1523,8 +1530,10 @@ reserve_closed_cb (
   {
     struct TALER_AUDITORDB_RowInconsistency ri = {
       .row_id = rowid,
-      .row_table = "reserves_closures",
-      .diagnostic = "closing fee above reserve balance (and closed anyway)"
+      .row_table
+        = (char *) "reserves_closures",
+      .diagnostic
+        = (char *) "closing fee above reserve balance (and closed anyway)"
     };
     enum GNUNET_DB_QueryStatus qs;
 
@@ -1540,16 +1549,20 @@ reserve_closed_cb (
     GNUNET_free (rc);
     return GNUNET_OK;
   }
-  TALER_ARL_USE_PP (wire_reserve_close_id)
-    = GNUNET_MAX (TALER_ARL_USE_PP (wire_reserve_close_id),
-                  rowid + 1);
-  rc->receiver_account = TALER_payto_normalize (receiver_account);
+  rc->receiver_account.full_payto
+    = GNUNET_strdup (receiver_account.full_payto);
   rc->wtid = *wtid;
   rc->execution_date = execution_date;
   rc->rowid = rowid;
-  hash_rc (receiver_account,
+  hash_rc (rc->receiver_account,
            wtid,
            &key);
+  GNUNET_log (GNUNET_ERROR_TYPE_INFO,
+              "Discovered reserve closure %llu (%s) over %s benefiting %s\n",
+              (unsigned long long) rowid,
+              GNUNET_h2s (&key),
+              TALER_amount2s (amount_with_fee),
+              receiver_account.full_payto);
   (void) GNUNET_CONTAINER_multihashmap_put (
     reserve_closures,
     &key,
@@ -1603,7 +1616,6 @@ begin_transaction (void)
     TALER_ARL_GET_AB (total_wire_out),
     TALER_ARL_GET_AB (total_bad_amount_out_plus),
     TALER_ARL_GET_AB (total_bad_amount_out_minus),
-    TALER_ARL_GET_AB (total_amount_lag),
     TALER_ARL_GET_AB (total_closure_amount_lag),
     TALER_ARL_GET_AB (wire_debit_duplicate_transfer_subject_total),
     TALER_ARL_GET_AB (total_wire_out),
@@ -1672,7 +1684,9 @@ begin_transaction (void)
                 "Resuming wire debit audit at %llu\n",
                 (unsigned long long) TALER_ARL_USE_PP (wire_reserve_close_id));
   }
-
+  GNUNET_log (GNUNET_ERROR_TYPE_INFO,
+              "Iterating over reserve closures from %llu\n",
+              (unsigned long long) TALER_ARL_USE_PP (wire_reserve_close_id));
   qs = TALER_ARL_edb->select_reserve_closed_above_serial_id (
     TALER_ARL_edb->cls,
     TALER_ARL_USE_PP (wire_reserve_close_id),
@@ -1877,15 +1891,8 @@ main (int argc,
   };
   enum GNUNET_GenericReturnValue ret;
 
-  /* force linker to link against libtalerutil; if we do
-     not do this, the linker may "optimize" libtalerutil
-     away and skip #TALER_OS_init(), which we do need */
-  (void) TALER_project_data_default ();
-  if (GNUNET_OK !=
-      GNUNET_STRINGS_get_utf8_args (argc, argv,
-                                    &argc, &argv))
-    return EXIT_INVALIDARGUMENT;
   ret = GNUNET_PROGRAM_run (
+    TALER_AUDITOR_project_data (),
     argc,
     argv,
     "taler-helper-auditor-wire-debit",
@@ -1894,7 +1901,6 @@ main (int argc,
     options,
     &run,
     NULL);
-  GNUNET_free_nz ((void *) argv);
   if (GNUNET_SYSERR == ret)
     return EXIT_INVALIDARGUMENT;
   if (GNUNET_NO == ret)
