@@ -25,7 +25,8 @@
 
 
 struct TALER_AUDITORDB_Plugin *
-TALER_AUDITORDB_plugin_load (const struct GNUNET_CONFIGURATION_Handle *cfg)
+TALER_AUDITORDB_plugin_load (const struct GNUNET_CONFIGURATION_Handle *cfg,
+                             bool skip_preflight)
 {
   char *plugin_name;
   char *lib_name;
@@ -46,12 +47,25 @@ TALER_AUDITORDB_plugin_load (const struct GNUNET_CONFIGURATION_Handle *cfg)
                           "libtaler_plugin_auditordb_%s",
                           plugin_name);
   GNUNET_free (plugin_name);
-  plugin = GNUNET_PLUGIN_load (lib_name,
+  plugin = GNUNET_PLUGIN_load (TALER_AUDITOR_project_data (),
+                               lib_name,
                                (void *) cfg);
-  if (NULL != plugin)
-    plugin->library_name = lib_name;
-  else
+  if (NULL == plugin)
+  {
+    abort ();
     GNUNET_free (lib_name);
+    return NULL;
+  }
+  plugin->library_name = lib_name;
+  if ( (! skip_preflight) &&
+       (GNUNET_OK !=
+        plugin->preflight (plugin->cls)) )
+  {
+    GNUNET_log (GNUNET_ERROR_TYPE_ERROR,
+                "Database not ready. Try running taler-auditor-dbinit!\n");
+    TALER_AUDITORDB_plugin_unload (plugin);
+    return NULL;
+  }
   return plugin;
 }
 
