@@ -26,6 +26,7 @@
 #include "pg_delete_generic.h"
 #include "pg_delete_pending_deposit.h"
 #include "pg_delete_purse_info.h"
+#include "pg_delete_reserve_in_inconsistency.h"
 #include "pg_del_denomination_balance.h"
 #include "pg_del_reserve_info.h"
 #include "pg_get_auditor_progress.h"
@@ -47,6 +48,7 @@
 #include "pg_insert_pending_deposit.h"
 #include "pg_insert_purse_info.h"
 #include "pg_insert_reserve_info.h"
+#include "pg_select_reserve_in_inconsistency.h"
 #include "pg_select_historic_denom_revenue.h"
 #include "pg_select_historic_reserve_revenue.h"
 #include "pg_get_progress_points.h"
@@ -95,6 +97,7 @@
 #include "pg_insert_reserve_balance_insufficient_inconsistency.h"
 
 #include "pg_get_reserve_in_inconsistency.h"
+#include "pg_lookup_reserve_in_inconsistency.h"
 #include "pg_insert_reserve_in_inconsistency.h"
 
 #include "pg_get_reserve_not_closed_inconsistency.h"
@@ -656,7 +659,10 @@ libtaler_plugin_auditordb_postgres_init (void *cls)
 
   plugin->insert_reserve_in_inconsistency =
     &TAH_PG_insert_reserve_in_inconsistency;
-  plugin->get_reserve_in_inconsistency = &TAH_PG_get_reserve_in_inconsistency;
+  plugin->get_reserve_in_inconsistency
+    = &TAH_PG_get_reserve_in_inconsistency;
+  plugin->lookup_reserve_in_inconsistency
+    = &TAH_PG_lookup_reserve_in_inconsistency;
 
   plugin->insert_reserve_not_closed_inconsistency =
     &TAH_PG_insert_reserve_not_closed_inconsistency;
@@ -693,6 +699,10 @@ libtaler_plugin_auditordb_postgres_init (void *cls)
     = &TAH_PG_insert_wire_out_inconsistency;
   plugin->get_wire_out_inconsistency
     = &TAH_PG_get_wire_out_inconsistency;
+  plugin->select_reserve_in_inconsistency
+    = &TAH_PG_select_reserve_in_inconsistency;
+  plugin->delete_reserve_in_inconsistency
+    = &TAH_PG_delete_reserve_in_inconsistency;
 
   plugin->insert_reserve_balance_summary_wrong_inconsistency =
     &TAH_PG_insert_reserve_balance_summary_wrong_inconsistency;
