@@ -185,12 +185,22 @@ run (void *cls)
 {
   struct GNUNET_CONFIGURATION_Handle *cfg = cls;
   uint64_t rowid;
+  struct TALER_Amount value;
+  struct TALER_Amount fee_withdraw;
+  struct TALER_Amount fee_deposit;
+  struct TALER_Amount fee_refresh;
+  struct TALER_Amount fee_refund;
+  struct TALER_ReservePublicKeyP reserve_pub;
+  struct TALER_DenominationPrivateKey denom_priv;
+  struct TALER_DenominationPublicKey denom_pub;
+  struct GNUNET_TIME_Timestamp date;
 
   GNUNET_log (GNUNET_ERROR_TYPE_INFO,
               "loading database plugin\n");
 
   if (NULL ==
-      (plugin = TALER_AUDITORDB_plugin_load (cfg)))
+      (plugin = TALER_AUDITORDB_plugin_load (cfg,
+                                             true)))
   {
     result = 77;
     return;
@@ -219,12 +229,6 @@ run (void *cls)
   GNUNET_log (GNUNET_ERROR_TYPE_INFO,
               "initializing\n");
 
-  struct TALER_Amount value;
-  struct TALER_Amount fee_withdraw;
-  struct TALER_Amount fee_deposit;
-  struct TALER_Amount fee_refresh;
-  struct TALER_Amount fee_refund;
-
   GNUNET_assert (GNUNET_OK ==
                  TALER_string_to_amount (CURRENCY ":1.000010",
                                          &value));
@@ -240,12 +244,6 @@ run (void *cls)
   GNUNET_assert (GNUNET_OK ==
                  TALER_string_to_amount (CURRENCY ":0.000014",
                                          &fee_refund));
-
-  struct TALER_ReservePublicKeyP reserve_pub;
-  struct TALER_DenominationPrivateKey denom_priv;
-  struct TALER_DenominationPublicKey denom_pub;
-  struct GNUNET_TIME_Timestamp date;
-
   RND_BLK (&reserve_pub);
   RND_BLK (&rnd_hash);
   GNUNET_assert (GNUNET_OK ==
@@ -297,12 +295,18 @@ run (void *cls)
     GNUNET_assert (GNUNET_OK ==
                    TALER_string_to_amount (CURRENCY ":53.456789",
                                            &rfb.history_fee_balance));
-    FAILIF (GNUNET_DB_STATUS_SUCCESS_ONE_RESULT !=
-            plugin->insert_reserve_info (plugin->cls,
-                                         &reserve_pub,
-                                         &rfb,
-                                         past,
-                                         "payto://bla/blub"));
+    {
+      struct TALER_FullPayto pt = {
+        .full_payto = (char *) "payto://bla/blub?receiver-name=blub"
+      };
+
+      FAILIF (GNUNET_DB_STATUS_SUCCESS_ONE_RESULT !=
+              plugin->insert_reserve_info (plugin->cls,
+                                           &reserve_pub,
+                                           &rfb,
+                                           past,
+                                           pt));
+    }
     GNUNET_log (GNUNET_ERROR_TYPE_INFO,
                 "Test: update_reserve_info\n");
     FAILIF (GNUNET_DB_STATUS_SUCCESS_ONE_RESULT !=
@@ -313,7 +317,7 @@ run (void *cls)
     GNUNET_log (GNUNET_ERROR_TYPE_INFO,
                 "Test: get_reserve_info\n");
     {
-      char *payto;
+      struct TALER_FullPayto payto;
 
       FAILIF (GNUNET_DB_STATUS_SUCCESS_ONE_RESULT !=
               plugin->get_reserve_info (plugin->cls,
@@ -322,9 +326,9 @@ run (void *cls)
                                         &rfb2,
                                         &date,
                                         &payto));
-      FAILIF (0 != strcmp (payto,
-                           "payto://bla/blub"));
-      GNUNET_free (payto);
+      FAILIF (0 != strcmp (payto.full_payto,
+                           "payto://bla/blub?receiver-name=blub"));
+      GNUNET_free (payto.full_payto);
     }
     FAILIF ( (0 != GNUNET_memcmp (&date,
                                   &future))
@@ -344,12 +348,11 @@ run (void *cls)
   }
 
   {
-    GNUNET_log (GNUNET_ERROR_TYPE_INFO,
-                "Test: insert_denomination_balance\n");
-
     struct TALER_AUDITORDB_DenominationCirculationData dcd;
     struct TALER_AUDITORDB_DenominationCirculationData dcd2;
 
+    GNUNET_log (GNUNET_ERROR_TYPE_INFO,
+                "Test: insert_denomination_balance\n");
     GNUNET_assert (GNUNET_OK ==
                    TALER_string_to_amount (CURRENCY ":12.345678",
                                            &dcd.denom_balance));
@@ -484,7 +487,6 @@ main (int argc,
   GNUNET_log_setup (argv[0],
                     "WARNING",
                     NULL);
-  TALER_OS_init ();
   if (NULL == (plugin_name = strrchr (argv[0],
                                       (int) '-')))
   {
@@ -497,7 +499,7 @@ main (int argc,
                           plugin_name);
   (void) GNUNET_asprintf (&config_filename,
                           "%s.conf", testname);
-  cfg = GNUNET_CONFIGURATION_create ();
+  cfg = GNUNET_CONFIGURATION_create (TALER_AUDITOR_project_data ());
   if (GNUNET_OK !=
       GNUNET_CONFIGURATION_parse (cfg,
                                   config_filename))
