@@ -89,7 +89,8 @@ run (void *cls)
   GNUNET_log (GNUNET_ERROR_TYPE_INFO,
               "loading database plugin\n");
   if (NULL ==
-      (plugin = TALER_AUDITORDB_plugin_load (cfg)))
+      (plugin = TALER_AUDITORDB_plugin_load (cfg,
+                                             true)))
   {
     GNUNET_log (GNUNET_ERROR_TYPE_WARNING,
                 "Failed to connect to database\n");
@@ -178,56 +179,68 @@ run (void *cls)
    * Test2 = 123
    * Test3 = 245
    * Let's make sure that's the case! */
-  uint64_t value;
-  uint64_t valueNX;
-  uint64_t value3;
-  GNUNET_assert (
-    3 ==
-    plugin->get_auditor_progress (
-      plugin->cls,
-      "Test",
-      &value,
-      "TestNX",
-      &valueNX,
-      "Test3",
-      &value3,
-      NULL)
-    );
-  GNUNET_assert (value == 42);
-  GNUNET_assert (valueNX == 0);
-  GNUNET_assert (value3 == 245);
+  {
+    uint64_t value;
+    uint64_t valueNX;
+    uint64_t value3;
 
+    GNUNET_assert (
+      3 ==
+      plugin->get_auditor_progress (
+        plugin->cls,
+        "Test",
+        &value,
+        "TestNX",
+        &valueNX,
+        "Test3",
+        &value3,
+        NULL)
+      );
+    GNUNET_assert (value == 42);
+    GNUNET_assert (valueNX == 0);
+    GNUNET_assert (value3 == 245);
+  }
   /* Ensure the rest are also at their expected values */
-  GNUNET_assert (
-    GNUNET_DB_STATUS_SUCCESS_ONE_RESULT ==
-    plugin->get_auditor_progress (
-      plugin->cls,
-      "Test2",
-      &value,
-      NULL)
-    );
-  GNUNET_assert (value == 123);
-  GNUNET_assert (
-    GNUNET_DB_STATUS_SUCCESS_ONE_RESULT ==
-    plugin->get_auditor_progress (
-      plugin->cls,
-      "Test3",
-      &value,
-      NULL)
-    );
-  GNUNET_assert (value == 245);
+  {
+    uint64_t value;
 
-  /* Try fetching value that does not exist */
-  GNUNET_assert (
-    GNUNET_DB_STATUS_SUCCESS_ONE_RESULT ==
-    plugin->get_auditor_progress (
-      plugin->cls,
-      "TestNX",
-      &value,
-      NULL)
-    );
-  GNUNET_assert (0 == value);
+    GNUNET_assert (
+      GNUNET_DB_STATUS_SUCCESS_ONE_RESULT ==
+      plugin->get_auditor_progress (
+        plugin->cls,
+        "Test2",
+        &value,
+        NULL)
+      );
+    GNUNET_assert (value == 123);
+  }
+  {
+    uint64_t value;
 
+    GNUNET_assert (
+      GNUNET_DB_STATUS_SUCCESS_ONE_RESULT ==
+      plugin->get_auditor_progress (
+        plugin->cls,
+        "Test3",
+        &value,
+        NULL)
+      );
+    GNUNET_assert (value == 245);
+  }
+  {
+    uint64_t value;
+
+    /* Try fetching value that does not exist */
+    GNUNET_assert (
+      GNUNET_DB_STATUS_SUCCESS_ONE_RESULT ==
+      plugin->get_auditor_progress (
+        plugin->cls,
+        "TestNX",
+        &value,
+        NULL)
+      );
+    GNUNET_assert (0 == value);
+  }
 
   /* Test inserting a blank value, should tell us one result */
   GNUNET_assert (
@@ -357,7 +370,6 @@ main (int argc,
 
   (void) argc;
   result = -1;
-  TALER_OS_init ();
   GNUNET_log_setup (argv[0],
                     "INFO",
                     NULL);
@@ -374,7 +386,7 @@ main (int argc,
   (void) GNUNET_asprintf (&config_filename,
                           "%s.conf",
                           testname);
-  cfg = GNUNET_CONFIGURATION_create ();
+  cfg = GNUNET_CONFIGURATION_create (TALER_AUDITOR_project_data ());
   if (GNUNET_OK !=
       GNUNET_CONFIGURATION_parse (cfg,
                                   config_filename))
