@@ -136,7 +136,7 @@ static struct TALER_TESTING_Timer timings[] = {
  * @param label string to add to the table
  * @return same string, now stored in the table
  */
-const char *
+static const char *
 add_label (char *label)
 {
   if (label_off == label_len)
@@ -438,7 +438,8 @@ main (int argc,
                                "fakebank",
                                "we are using fakebank",
                                &use_fakebank),
-    GNUNET_GETOPT_option_help ("taler-bank benchmark"),
+    GNUNET_GETOPT_option_help (TALER_EXCHANGE_project_data (),
+                               "taler-bank benchmark"),
     GNUNET_GETOPT_option_string ('l',
                                  "logfile",
                                  "LF",
@@ -493,7 +494,7 @@ main (int argc,
   GNUNET_log_setup ("taler-bank-benchmark",
                     loglev,
                     logfile);
-  cfg = GNUNET_CONFIGURATION_create ();
+  cfg = GNUNET_CONFIGURATION_create (TALER_EXCHANGE_project_data ());
   if (GNUNET_OK !=
       GNUNET_CONFIGURATION_load (cfg,
                                  cfg_filename))
@@ -504,6 +505,7 @@ main (int argc,
   }
   if (GNUNET_OK !=
       TALER_config_get_currency (cfg,
+                                 "exchange",
                                  &currency))
   {
     GNUNET_CONFIGURATION_destroy (cfg);
@@ -546,7 +548,7 @@ main (int argc,
              howmany_reserves,
              howmany_clients,
              GNUNET_STRINGS_relative_time_to_string (duration,
-                                                     GNUNET_YES));
+                                                     true));
     if (! GNUNET_TIME_relative_is_zero (duration))
     {
       tps = ((unsigned long long) howmany_reserves) * howmany_clients * 1000LLU
