@@ -224,6 +224,20 @@ static unsigned int connection_timeout = 30;
  */
 static int connection_close;
 
+/**
+ * Allows banks to select a custom UI/UX for certain bank-specific
+ * wallet functions, such as specific texts for buttons based on
+ * legal requirements.
+ */
+char *TEH_bank_compliance_language;
+
+/**
+ * Determines the set of AML forms (and other bank-specific settings)
+ * to be selected for the AML SPA.
+ * legal requirements.
+ */
+char *TEH_aml_spa_dialect;
+
 /**
  * Option set to #GNUNET_YES if KYC/AML are enabled.
  */
@@ -2262,6 +2276,16 @@ exchange_serve_process_config (const char *cfg_fn)
   {
     toplevel_redirect_url = GNUNET_strdup ("/terms");
   }
+  (void)
+  GNUNET_CONFIGURATION_get_value_string (TEH_cfg,
+                                         "exchange",
+                                         "BANK_COMPLIANCE_LANGUAGE",
+                                         &TEH_bank_compliance_language);
+  (void)
+  GNUNET_CONFIGURATION_get_value_string (TEH_cfg,
+                                         "exchange",
+                                         "AML_SPA_DIALECT",
+                                         &TEH_aml_spa_dialect);
   if (GNUNET_OK !=
       TALER_config_get_currency (TEH_cfg,
                                  "exchange",
