@@ -102,6 +102,20 @@ extern struct TALER_AttributeEncryptionKeyP TEH_attribute_key;
  */
 extern struct TALER_EXCHANGEDB_Plugin *TEH_plugin;
 
+/**
+ * Allows banks to select a custom UI/UX for certain bank-specific
+ * wallet functions, such as specific texts for buttons based on
+ * legal requirements.
+ */
+extern char *TEH_bank_compliance_language;
+
+/**
+ * Determines the set of AML forms (and other bank-specific settings)
+ * to be selected for the AML SPA.
+ * legal requirements.
+ */
+extern char *TEH_aml_spa_dialect;
+
 /**
  * JSON array with hard limits for /keys response.
  */
