@@ -72,7 +72,7 @@ struct KycProofContext
   /**
    * KYC AML trigger operation.
    */
-  struct TEH_KycAmlTrigger *kat;
+  struct TEH_KycMeasureRunContext *kat;
 
   /**
    * Process information about the user for the plugin from the database, can
@@ -89,13 +89,28 @@ struct KycProofContext
   /**
    * Hash of payment target URI this is about.
    */
-  struct TALER_PaytoHashP h_payto;
+  struct TALER_NormalizedPaytoHashP h_payto;
 
   /**
-   * HTTP response to return.
+   * Final HTTP response to return.
    */
   struct MHD_Response *response;
 
+  /**
+   * Final HTTP response code to return.
+   */
+  unsigned int response_code;
+
+  /**
+   * HTTP response from the KYC provider plugin.
+   */
+  struct MHD_Response *proof_response;
+
+  /**
+   * HTTP response code from the KYC provider plugin.
+   */
+  unsigned int proof_response_code;
+
   /**
    * Provider configuration section name of the logic we are running.
    */
@@ -106,11 +121,6 @@ struct KycProofContext
    */
   uint64_t process_row;
 
-  /**
-   * HTTP response code to return.
-   */
-  unsigned int response_code;
-
   /**
    * True if we are suspended,
    */
@@ -130,6 +140,46 @@ static struct KycProofContext *kpc_head;
 static struct KycProofContext *kpc_tail;
 
 
+/**
+ * Generate HTML error for @a connection using @a template.
+ *
+ * @param connection HTTP client connection
+ * @param template template to expand
+ * @param[in,out] http_status HTTP status of the response
+ * @param ec Taler error code to return
+ * @param message extended message to return
+ * @return MHD response object
+ */
+static struct MHD_Response *
+make_html_error (struct MHD_Connection *connection,
+                 const char *template,
+                 unsigned int *http_status,
+                 enum TALER_ErrorCode ec,
+                 const char *message)
+{
+  struct MHD_Response *response = NULL;
+  json_t *body;
+
+  body = GNUNET_JSON_PACK (
+    GNUNET_JSON_pack_allow_null (
+      GNUNET_JSON_pack_string ("message",
+                               message)),
+    TALER_JSON_pack_ec (
+      ec));
+  GNUNET_break (
+    GNUNET_SYSERR !=
+    TALER_TEMPLATING_build (connection,
+                            http_status,
+                            template,
+                            NULL,
+                            NULL,
+                            body,
+                            &response));
+  json_decref (body);
+  return response;
+}
+
+
 /**
  * Resume processing the @a kpc request.
  *
@@ -169,65 +219,51 @@ TEH_kyc_proof_cleanup (void)
  * Function called after the KYC-AML trigger is done.
  *
  * @param cls closure
- * @param http_status final HTTP status to return
- * @param[in] response final HTTP ro return
+ * @param ec error code or 0 on success
+ * @param detail error message or NULL on success / no info
  */
 static void
 proof_finish (
   void *cls,
-  unsigned int http_status,
-  struct MHD_Response *response)
+  enum TALER_ErrorCode ec,
+  const char *detail)
 {
   struct KycProofContext *kpc = cls;
 
   kpc->kat = NULL;
-  GNUNET_assert (NULL == kpc->response);
-  kpc->response_code = http_status;
-  kpc->response = response;
+  if (TALER_EC_NONE != ec)
+  {
+    kpc->response_code = TALER_ErrorCode_get_http_status (ec);
+    GNUNET_break (5 != kpc->response_code / 100);
+    GNUNET_assert (kpc->response_code != UINT_MAX);
+    GNUNET_log (GNUNET_ERROR_TYPE_INFO,
+                "Templating error response for %d and HTTP status %u\n",
+                (int) ec,
+                kpc->response_code);
+    kpc->response = make_html_error (
+      kpc->rc->connection,
+      "kyc-proof-internal-error",
+      &kpc->response_code,
+      ec,
+      detail);
+  }
+  else
+  {
+    GNUNET_assert (NULL != kpc->proof_response);
+    kpc->response_code = kpc->proof_response_code;
+    kpc->response = kpc->proof_response;
+    kpc->proof_response = NULL;
+    kpc->proof_response_code = 0;
+  }
+  GNUNET_assert (NULL != kpc->response);
+  GNUNET_log (GNUNET_ERROR_TYPE_INFO,
+              "Resuming with response %p and status %u\n",
+              kpc->response,
+              kpc->response_code);
   kpc_resume (kpc);
 }
 
 
-/**
- * Generate HTML error for @a connection using @a template.
- *
- * @param connection HTTP client connection
- * @param template template to expand
- * @param[in,out] http_status HTTP status of the response
- * @param ec Taler error code to return
- * @param message extended message to return
- * @return MHD response object
- */
-static struct MHD_Response *
-make_html_error (struct MHD_Connection *connection,
-                 const char *template,
-                 unsigned int *http_status,
-                 enum TALER_ErrorCode ec,
-                 const char *message)
-{
-  struct MHD_Response *response = NULL;
-  json_t *body;
-
-  body = GNUNET_JSON_PACK (
-    GNUNET_JSON_pack_allow_null (
-      GNUNET_JSON_pack_string ("message",
-                               message)),
-    TALER_JSON_pack_ec (
-      ec));
-  GNUNET_break (
-    GNUNET_SYSERR !=
-    TALER_TEMPLATING_build (connection,
-                            http_status,
-                            template,
-                            NULL,
-                            NULL,
-                            body,
-                            &response));
-  json_decref (body);
-  return response;
-}
-
-
 /**
  * Respond with an HTML message on the given @a rc.
  *
@@ -269,6 +305,7 @@ respond_html_ec (struct TEH_RequestContext *rc,
  *
  * @param cls closure
  * @param status KYC status
+ * @param provider_name name of the provider
  * @param provider_user_id set to user ID at the provider, or NULL if not supported or unknown
  * @param provider_legitimization_id set to legitimization process ID at the provider, or NULL if not supported or unknown
  * @param expiration until when is the KYC check valid
@@ -280,6 +317,7 @@ static void
 proof_cb (
   void *cls,
   enum TALER_KYCLOGIC_KycStatus status,
+  const char *provider_name,
   const char *provider_user_id,
   const char *provider_legitimization_id,
   struct GNUNET_TIME_Absolute expiration,
@@ -290,8 +328,11 @@ proof_cb (
   struct KycProofContext *kpc = cls;
   struct TEH_RequestContext *rc = kpc->rc;
   struct GNUNET_AsyncScopeSave old_scope;
+  enum GNUNET_DB_QueryStatus qs;
 
   kpc->ph = NULL;
+  kpc->proof_response = response;
+  kpc->proof_response_code = http_status;
   GNUNET_async_scope_enter (&rc->async_scope_id,
                             &old_scope);
   switch (status)
@@ -300,29 +341,35 @@ proof_cb (
     GNUNET_log (GNUNET_ERROR_TYPE_INFO,
                 "KYC process #%llu succeeded with KYC provider\n",
                 (unsigned long long) kpc->process_row);
-    kpc->kat = TEH_kyc_finished (
-      &rc->async_scope_id,
+    qs = TEH_kyc_store_attributes (
       kpc->process_row,
       &kpc->h_payto,
-      kpc->provider_name,
+      provider_name,
       provider_user_id,
       provider_legitimization_id,
       expiration,
-      attributes,
-      http_status,
-      response,
+      attributes);
+    if (0 >= qs)
+    {
+      GNUNET_break (0);
+      proof_finish (kpc,
+                    TALER_EC_GENERIC_DB_STORE_FAILED,
+                    "kyc_store_attributes");
+      return;
+    }
+
+    kpc->kat = TEH_kyc_run_measure_for_attributes (
+      &rc->async_scope_id,
+      kpc->process_row,
+      &kpc->h_payto,
       &proof_finish,
       kpc);
-    response = NULL; /* taken over by TEH_kyc_finished */
     if (NULL == kpc->kat)
     {
-      http_status = MHD_HTTP_INTERNAL_SERVER_ERROR;
-      response = make_html_error (
-        kpc->rc->connection,
-        "kyc-proof-internal-error",
-        &http_status,
-        TALER_EC_EXCHANGE_GENERIC_BAD_CONFIGURATION,
-        "[exchange] AML_KYC_TRIGGER");
+      GNUNET_break (0);
+      proof_finish (kpc,
+                    TALER_EC_EXCHANGE_GENERIC_BAD_CONFIGURATION,
+                    "[exchange] AML_KYC_TRIGGER");
     }
     break;
   case TALER_KYCLOGIC_STATUS_FAILED:
@@ -341,16 +388,12 @@ proof_cb (
       char *msg;
 
       /* OAuth2 server had a problem, do NOT log this as a KYC failure */
-      if (NULL != response)
-        MHD_destroy_response (response);
+      GNUNET_break (0);
       GNUNET_asprintf (&msg,
                        "Failure by KYC provider (HTTP status %u)\n",
                        http_status);
-      http_status = MHD_HTTP_BAD_GATEWAY;
-      response = make_html_error (
-        kpc->rc->connection,
-        "kyc-proof-internal-error",
-        &http_status,
+      proof_finish (
+        kpc,
         TALER_EC_EXCHANGE_KYC_GENERIC_PROVIDER_UNEXPECTED_REPLY,
         msg);
       GNUNET_free (msg);
@@ -367,15 +410,20 @@ proof_cb (
             TALER_EC_EXCHANGE_GENERIC_KYC_FAILED))
       {
         GNUNET_break (0);
-        if (NULL != response)
-          MHD_destroy_response (response);
-        http_status = MHD_HTTP_INTERNAL_SERVER_ERROR;
-        response = make_html_error (
-          kpc->rc->connection,
-          "kyc-proof-internal-error",
-          &http_status,
+        proof_finish (
+          kpc,
           TALER_EC_GENERIC_DB_STORE_FAILED,
-          "insert_kyc_failure");
+          "TEH_kyc_failed");
+      }
+      else
+      {
+        GNUNET_log (GNUNET_ERROR_TYPE_WARNING,
+                    "KYC process #%llu failed with status %d\n",
+                    (unsigned long long) kpc->process_row,
+                    status);
+        proof_finish (kpc,
+                      TALER_EC_NONE,
+                      NULL);
       }
     }
     break;
@@ -388,16 +436,6 @@ proof_cb (
                 (int) status);
     break;
   }
-  if (NULL == kpc->kat)
-  {
-    GNUNET_log (GNUNET_ERROR_TYPE_INFO,
-                "KYC process #%llu failed with status %d\n",
-                (unsigned long long) kpc->process_row,
-                status);
-    proof_finish (kpc,
-                  http_status,
-                  response);
-  }
   GNUNET_async_scope_restore (&old_scope);
 }
 
@@ -419,7 +457,7 @@ clean_kpc (struct TEH_RequestContext *rc)
   }
   if (NULL != kpc->kat)
   {
-    TEH_kyc_finished_cancel (kpc->kat);
+    TEH_kyc_run_measure_cancel (kpc->kat);
     kpc->kat = NULL;
   }
   if (NULL != kpc->response)
@@ -427,6 +465,11 @@ clean_kpc (struct TEH_RequestContext *rc)
     MHD_destroy_response (kpc->response);
     kpc->response = NULL;
   }
+  if (NULL != kpc->proof_response)
+  {
+    MHD_destroy_response (kpc->proof_response);
+    kpc->proof_response = NULL;
+  }
   GNUNET_free (kpc->provider_user_id);
   GNUNET_free (kpc->provider_legitimization_id);
   GNUNET_free (kpc);
@@ -508,6 +551,7 @@ TEH_handler_kyc_proof (
       {
       case GNUNET_DB_STATUS_HARD_ERROR:
       case GNUNET_DB_STATUS_SOFT_ERROR:
+        GNUNET_break (0);
         return respond_html_ec (
           rc,
           MHD_HTTP_INTERNAL_SERVER_ERROR,
