@@ -57,7 +57,7 @@ struct KycWebhookContext
   /**
    * Handle for the KYC-AML trigger interaction.
    */
-  struct TEH_KycAmlTrigger *kat;
+  struct TEH_KycMeasureRunContext *kat;
 
   /**
    * Plugin responsible for the webhook.
@@ -81,15 +81,29 @@ struct KycWebhookContext
   struct TALER_KYCLOGIC_WebhookHandle *wh;
 
   /**
-   * HTTP response to return.
+   * Final HTTP response to return.
    */
   struct MHD_Response *response;
 
   /**
-   * HTTP response code to return.
+   * Final HTTP response code to return.
    */
   unsigned int response_code;
 
+  /**
+   * Response from the webhook plugin.
+   *
+   * Will become the final response on successfully
+   * running the measure with the new attributes.
+   */
+  struct MHD_Response *webhook_response;
+
+  /**
+   * Response code to return for the webhook plugin
+   * response.
+   */
+  unsigned int webhook_response_code;
+
   /**
    * #GNUNET_YES if we are suspended,
    * #GNUNET_NO if not.
@@ -150,21 +164,35 @@ TEH_kyc_webhook_cleanup (void)
  * Function called after the KYC-AML trigger is done.
  *
  * @param cls closure with a `struct KycWebhookContext *`
- * @param http_status final HTTP status to return
- * @param[in] response final HTTP ro return
+ * @param ec error code or 0 on success
+ * @param detail error message or NULL on success / no info
  */
 static void
 kyc_aml_webhook_finished (
   void *cls,
-  unsigned int http_status,
-  struct MHD_Response *response)
+  enum TALER_ErrorCode ec,
+  const char *detail)
 {
   struct KycWebhookContext *kwh = cls;
 
   kwh->kat = NULL;
   GNUNET_assert (NULL == kwh->response);
-  kwh->response = response;
-  kwh->response_code = http_status;
+  if (TALER_EC_NONE != ec)
+  {
+    kwh->response_code = MHD_HTTP_INTERNAL_SERVER_ERROR;
+    kwh->response = TALER_MHD_make_error (
+      ec,
+      detail
+      );
+  }
+  else
+  {
+    GNUNET_assert (NULL != kwh->webhook_response);
+    kwh->response_code = kwh->webhook_response_code;
+    kwh->response = kwh->webhook_response;
+    kwh->webhook_response = NULL;
+    kwh->webhook_response_code = 0;
+  }
   kwh_resume (kwh);
 }
 
@@ -191,7 +219,7 @@ static void
 webhook_finished_cb (
   void *cls,
   uint64_t process_row,
-  const struct TALER_PaytoHashP *account_id,
+  const struct TALER_NormalizedPaytoHashP *account_id,
   const char *provider_name,
   const char *provider_user_id,
   const char *provider_legitimization_id,
@@ -202,35 +230,43 @@ webhook_finished_cb (
   struct MHD_Response *response)
 {
   struct KycWebhookContext *kwh = cls;
+  enum GNUNET_DB_QueryStatus qs;
 
   kwh->wh = NULL;
+  kwh->webhook_response = response;
+  kwh->webhook_response_code = http_status;
   switch (status)
   {
   case TALER_KYCLOGIC_STATUS_SUCCESS:
-    kwh->kat = TEH_kyc_finished (
-      &kwh->rc->async_scope_id,
+    qs = TEH_kyc_store_attributes (
       process_row,
       account_id,
       provider_name,
       provider_user_id,
       provider_legitimization_id,
       expiration,
-      attributes,
-      http_status,
-      response,
+      attributes);
+    if (0 >= qs)
+    {
+      GNUNET_break (0);
+      kyc_aml_webhook_finished (kwh,
+                                TALER_EC_GENERIC_DB_STORE_FAILED,
+                                "kyc_store_attributes");
+      return;
+    }
+    kwh->kat = TEH_kyc_run_measure_for_attributes (
+      &kwh->rc->async_scope_id,
+      process_row,
+      account_id,
       &kyc_aml_webhook_finished,
       kwh);
     if (NULL == kwh->kat)
     {
-      if (NULL != response)
-        MHD_destroy_response (response);
-      http_status = MHD_HTTP_INTERNAL_SERVER_ERROR;
-      response = TALER_MHD_make_error (
-        TALER_EC_EXCHANGE_GENERIC_BAD_CONFIGURATION,
-        "[exchange] AML_KYC_TRIGGER");
-      break;
+      kyc_aml_webhook_finished (kwh,
+                                TALER_EC_EXCHANGE_GENERIC_BAD_CONFIGURATION,
+                                "[exchange] AML_KYC_TRIGGER");
     }
-    return;
+    break;
   case TALER_KYCLOGIC_STATUS_FAILED:
   case TALER_KYCLOGIC_STATUS_PROVIDER_FAILED:
   case TALER_KYCLOGIC_STATUS_USER_ABORTED:
@@ -251,12 +287,9 @@ webhook_finished_cb (
           TALER_EC_EXCHANGE_GENERIC_KYC_FAILED))
     {
       GNUNET_break (0);
-      if (NULL != response)
-        MHD_destroy_response (response);
-      http_status = MHD_HTTP_INTERNAL_SERVER_ERROR;
-      response = TALER_MHD_make_error (
-        TALER_EC_GENERIC_DB_STORE_FAILED,
-        "insert_kyc_failure");
+      kyc_aml_webhook_finished (kwh,
+                                TALER_EC_GENERIC_DB_STORE_FAILED,
+                                "TEH_kyc_failed");
     }
     break;
   default:
@@ -267,12 +300,11 @@ webhook_finished_cb (
       provider_legitimization_id,
       (unsigned long long) process_row,
       (int) status);
+    kyc_aml_webhook_finished (kwh,
+                              TALER_EC_NONE,
+                              NULL);
     break;
   }
-  GNUNET_break (NULL == kwh->kat);
-  kyc_aml_webhook_finished (kwh,
-                            http_status,
-                            response);
 }
 
 
@@ -293,7 +325,7 @@ clean_kwh (struct TEH_RequestContext *rc)
   }
   if (NULL != kwh->kat)
   {
-    TEH_kyc_finished_cancel (kwh->kat);
+    TEH_kyc_run_measure_cancel (kwh->kat);
     kwh->kat = NULL;
   }
   if (NULL != kwh->response)
@@ -301,6 +333,11 @@ clean_kwh (struct TEH_RequestContext *rc)
     MHD_destroy_response (kwh->response);
     kwh->response = NULL;
   }
+  if (NULL != kwh->webhook_response)
+  {
+    MHD_destroy_response (kwh->webhook_response);
+    kwh->webhook_response = NULL;
+  }
   GNUNET_free (kwh);
 }
 
