@@ -15,32 +15,34 @@
 --
 
 DROP FUNCTION IF EXISTS exchange_do_insert_aml_decision;
-CREATE OR REPLACE FUNCTION exchange_do_insert_aml_decision(
-  IN in_h_payto BYTEA,
+CREATE FUNCTION exchange_do_insert_aml_decision(
+  IN in_payto_uri TEXT, -- can be NULL!
+  IN in_h_normalized_payto BYTEA,
+  IN in_h_full_payto BYTEA, -- can be NULL!
   IN in_decision_time INT8,
   IN in_expiration_time INT8,
-  IN in_properties TEXT,
+  IN in_properties TEXT, -- can be NULL
   IN in_new_rules TEXT,
   IN in_to_investigate BOOLEAN,
-  IN in_new_measure_name TEXT,
-  IN in_jmeasures TEXT,
+  IN in_new_measure_name TEXT, -- can be NULL
+  IN in_jmeasures TEXT, -- can be NULL
   IN in_justification TEXT,
   IN in_decider_pub BYTEA,
   IN in_decider_sig BYTEA,
   IN in_notify_s TEXT,
   OUT out_invalid_officer BOOLEAN,
   OUT out_account_unknown BOOLEAN,
-  OUT out_last_date INT8)
+  OUT out_last_date INT8,
+  OUT out_legitimization_measure_serial_id INT8)
 LANGUAGE plpgsql
 AS $$
 DECLARE
   my_outcome_serial_id INT8;
   my_access_token BYTEA;
-  my_max_dp INT4;
 BEGIN
 
 out_account_unknown=FALSE;
-
+out_legitimization_measure_serial_id=0;
 
 -- Check officer is eligible to make decisions.
 PERFORM
@@ -60,65 +62,62 @@ out_invalid_officer=FALSE;
 SELECT decision_time
   INTO out_last_date
   FROM legitimization_outcomes
- WHERE h_payto=in_h_payto
+ WHERE h_payto=in_h_normalized_payto
    AND is_active
- ORDER BY decision_time DESC;
+ ORDER BY decision_time DESC, outcome_serial_id DESC;
 
 IF FOUND
 THEN
-  IF out_last_date >= in_decision_time
+  IF out_last_date > in_decision_time
   THEN
     -- Refuse to insert older decision.
     RETURN;
   END IF;
   UPDATE legitimization_outcomes
      SET is_active=FALSE
-   WHERE h_payto=in_h_payto
+   WHERE h_payto=in_h_normalized_payto
      AND is_active;
 ELSE
   out_last_date = 0;
 END IF;
 
--- Note: in_payto_uri is allowed to be NULL *if*
--- in_h_payto is already in wire_targets
 SELECT access_token
   INTO my_access_token
   FROM wire_targets
- WHERE wire_target_h_payto=in_h_payto;
+ WHERE h_normalized_payto=in_h_normalized_payto;
 
--- Very strange, should never happen that we
--- take an AML decision on an unknown account!
 IF NOT FOUND
 THEN
-  out_account_unknown=TRUE;
-  RETURN;
+  IF in_payto_uri IS NULL
+  THEN
+    -- AML decision on an unknown account without payto_uri => fail.
+    out_account_unknown=TRUE;
+    RETURN;
+  END IF;
+
+  INSERT INTO wire_targets
+    (wire_target_h_payto
+    ,h_normalized_payto
+    ,payto_uri)
+    VALUES
+    (in_h_full_payto
+    ,in_h_normalized_payto
+    ,in_payto_uri)
+    RETURNING access_token
+      INTO my_access_token;
 END IF;
 
 -- Did KYC measures get prescribed?
-IF in_jmeasures IS NULL
+IF in_jmeasures IS NOT NULL
 THEN
-  -- AML decision without measure: mark all
-  -- active measures finished!
-  UPDATE legitimization_measures
-     SET is_finished=TRUE
-   WHERE access_token=my_access_token
-     AND NOT is_finished;
-
-ELSE
-  -- Find current maximum DP
-  SELECT COALESCE(MAX(display_priority),0)
-    INTO my_max_dp
-    FROM legitimization_measures
-   WHERE access_token=my_access_token
-     AND NOT is_finished;
-
   -- First check if a perfectly equivalent legi measure
   -- already exists, to avoid creating tons of duplicates.
-  UPDATE legitimization_measures
-     SET display_priority=GREATEST(my_max_dp,display_priority)
-   WHERE access_token=my_access_token
-     AND jmeasures=in_jmeasures
-     AND NOT is_finished;
+  SELECT legitimization_measure_serial_id
+    INTO out_legitimization_measure_serial_id
+    FROM legitimization_measures
+    WHERE access_token=my_access_token
+      AND jmeasures=in_jmeasures
+      AND NOT is_finished;
 
   IF NOT FOUND
   THEN
@@ -132,15 +131,25 @@ ELSE
       (my_access_token
       ,in_decision_time
       ,in_jmeasures
-      ,my_max_dp + 1);
+      ,1)
+      RETURNING
+        legitimization_measure_serial_id
+      INTO
+        out_legitimization_measure_serial_id;
   END IF;
-
-  -- end if for where we had non-NULL in_jmeasures
+  -- end if for where we had in_jmeasures
 END IF;
 
+-- AML decision: mark all other active measures finished!
+UPDATE legitimization_measures
+  SET is_finished=TRUE
+  WHERE access_token=my_access_token
+    AND NOT is_finished
+    AND legitimization_measure_serial_id != out_legitimization_measure_serial_id;
+
 UPDATE legitimization_outcomes
    SET is_active=FALSE
- WHERE h_payto=in_h_payto
+ WHERE h_payto=in_h_normalized_payto
    -- this clause is a minor optimization to avoid
    -- updating outcomes that have long expired.
    AND expiration_time >= in_decision_time;
@@ -155,7 +164,7 @@ INSERT INTO legitimization_outcomes
   ,jnew_rules
   )
   VALUES
-  (in_h_payto
+  (in_h_normalized_payto
   ,in_decision_time
   ,in_expiration_time
   ,in_properties
@@ -176,7 +185,7 @@ INSERT INTO aml_history
   ,decider_pub
   ,decider_sig
   ) VALUES
-  (in_h_payto
+  (in_h_normalized_payto
   ,my_outcome_serial_id
   ,in_justification
   ,in_decider_pub
@@ -188,7 +197,7 @@ INSERT INTO kyc_alerts
   (h_payto
   ,trigger_type)
   VALUES
-  (in_h_payto,1)
+  (in_h_normalized_payto,1)
  ON CONFLICT DO NOTHING;
 
 EXECUTE FORMAT (
@@ -199,5 +208,5 @@ EXECUTE FORMAT (
 END $$;
 
 
-COMMENT ON FUNCTION exchange_do_insert_aml_decision(BYTEA, INT8, INT8, TEXT, TEXT, BOOLEAN, TEXT, TEXT, TEXT, BYTEA, BYTEA, TEXT)
+COMMENT ON FUNCTION exchange_do_insert_aml_decision(TEXT, BYTEA, BYTEA, INT8, INT8, TEXT, TEXT, BOOLEAN, TEXT, TEXT, TEXT, BYTEA, BYTEA, TEXT)
   IS 'Checks whether the AML officer is eligible to make AML decisions and if so inserts the decision into the table';
