@@ -33,24 +33,25 @@ static int result;
  * Report line of error if @a cond is true, and jump to label "drop".
  */
 #define FAILIF(cond)                            \
-  do {                                          \
-    if (! (cond)) {break;}                    \
-    GNUNET_break (0);                           \
-    goto drop;                                  \
-  } while (0)
+        do {                                          \
+          if (! (cond)) {break;}                    \
+          GNUNET_break (0);                           \
+          goto drop;                                  \
+        } while (0)
 
 
 /**
  * Initializes @a ptr with random data.
  */
 #define RND_BLK(ptr)                                                    \
-  GNUNET_CRYPTO_random_block (GNUNET_CRYPTO_QUALITY_WEAK, ptr, sizeof (*ptr))
+        GNUNET_CRYPTO_random_block (GNUNET_CRYPTO_QUALITY_WEAK, ptr, sizeof (* \
+                                                                             ptr))
 
 /**
  * Initializes @a ptr with zeros.
  */
 #define ZR_BLK(ptr) \
-  memset (ptr, 0, sizeof (*ptr))
+        memset (ptr, 0, sizeof (*ptr))
 
 /**
  * How many rounds do we average over?
@@ -85,7 +86,8 @@ run (void *cls)
   unsigned long long sqrs[sizeof (batches) / sizeof(*batches)];
 
   if (NULL ==
-      (plugin = TALER_EXCHANGEDB_plugin_load (cfg)))
+      (plugin = TALER_EXCHANGEDB_plugin_load (cfg,
+                                              true)))
   {
     GNUNET_break (0);
     result = 77;
@@ -123,7 +125,9 @@ run (void *cls)
       now = GNUNET_TIME_absolute_get ();
       ts = GNUNET_TIME_timestamp_get ();
       {
-        const char *sndr = "payto://x-taler-bank/localhost:8080/1";
+        struct TALER_FullPayto sndr = {
+          .full_payto = (char *) "payto://x-taler-bank/localhost:8080/1"
+        };
         struct TALER_ReservePublicKeyP reserve_pubs[lcm];
         struct TALER_EXCHANGEDB_ReserveInInfo reserves[lcm];
         enum GNUNET_DB_QueryStatus results[lcm];
@@ -210,7 +214,7 @@ main (int argc,
   (void) GNUNET_asprintf (&config_filename,
                           "%s.conf",
                           testname);
-  cfg = GNUNET_CONFIGURATION_create ();
+  cfg = GNUNET_CONFIGURATION_create (TALER_EXCHANGE_project_data ());
   if (GNUNET_OK !=
       GNUNET_CONFIGURATION_parse (cfg,
                                   config_filename))
