@@ -67,7 +67,6 @@ static int result;
  */
 static struct TALER_EXCHANGEDB_Plugin *plugin;
 
-static struct TALER_DenomFeeSet fees;
 
 static struct TALER_MerchantWireHashP h_wire_wt;
 
@@ -231,6 +230,7 @@ run (void *cls)
   unsigned long long duration_sq;
   struct TALER_EXCHANGEDB_RefreshRevealedCoin *ccoin;
   struct TALER_DenominationPublicKey *new_denom_pubs = NULL;
+  struct TALER_DenomFeeSet fees;
   unsigned int count = 0;
 
   ref = GNUNET_new_array (ROUNDS + 1,
@@ -240,7 +240,8 @@ run (void *cls)
   ZR_BLK (&cbc);
 
   if (NULL ==
-      (plugin = TALER_EXCHANGEDB_plugin_load (cfg)))
+      (plugin = TALER_EXCHANGEDB_plugin_load (cfg,
+                                              true)))
   {
     GNUNET_break (0);
     result = 77;
@@ -358,8 +359,8 @@ run (void *cls)
       .wallet_timestamp = ts,
       .refund_deadline = deadline,
       .wire_deadline = deadline,
-      .receiver_wire_account
-        = "payto://iban/DE67830654080004822650?receiver-name=Test"
+      .receiver_wire_account.full_payto
+        = (char *) "payto://iban/DE67830654080004822650?receiver-name=Test"
     };
 
     if (i >= ROUNDS)
@@ -599,7 +600,7 @@ main (int argc,
                      testname);
     GNUNET_free (testname);
   }
-  cfg = GNUNET_CONFIGURATION_create ();
+  cfg = GNUNET_CONFIGURATION_create (TALER_EXCHANGE_project_data ());
   if (GNUNET_OK !=
       GNUNET_CONFIGURATION_parse (cfg,
                                   config_filename))
