@@ -1,6 +1,6 @@
 /*
    This file is part of TALER
-   Copyright (C) 2022 Taler Systems SA
+   Copyright (C) 2022, 2024 Taler Systems SA
 
    TALER is free software; you can redistribute it and/or modify it under the
    terms of the GNU General Public License as published by the Free Software
@@ -72,7 +72,7 @@ get_transients_cb (void *cls,
   for (unsigned int i = 0; i<num_results; i++)
   {
     struct TALER_Amount amount;
-    char *payto_uri;
+    struct TALER_FullPayto payto_uri;
     struct TALER_WireTransferIdentifierRawP wtid;
     struct TALER_MerchantPublicKeyP merchant_pub;
     struct GNUNET_PQ_ResultSpec rs[] = {
@@ -81,7 +81,7 @@ get_transients_cb (void *cls,
       GNUNET_PQ_result_spec_auto_from_type ("wtid_raw",
                                             &wtid),
       GNUNET_PQ_result_spec_string ("payto_uri",
-                                    &payto_uri),
+                                    &payto_uri.full_payto),
       TALER_PQ_RESULT_SPEC_AMOUNT ("amount",
                                    &amount),
       GNUNET_PQ_result_spec_end
@@ -102,7 +102,7 @@ get_transients_cb (void *cls,
                       &wtid,
                       &merchant_pub,
                       &amount);
-    GNUNET_free (payto_uri);
+    GNUNET_free (payto_uri.full_payto);
     if (! cont)
       break;
   }
@@ -112,7 +112,7 @@ get_transients_cb (void *cls,
 enum GNUNET_DB_QueryStatus
 TEH_PG_find_aggregation_transient (
   void *cls,
-  const struct TALER_PaytoHashP *h_payto,
+  const struct TALER_NormalizedPaytoHashP *h_payto,
   TALER_EXCHANGEDB_TransientAggregationCallback cb,
   void *cb_cls)
 {
@@ -132,13 +132,14 @@ TEH_PG_find_aggregation_transient (
   PREPARE (pg,
            "find_transient_aggregations",
            "SELECT"
-           "  amount"
-           " ,wtid_raw"
-           " ,merchant_pub"
-           " ,payto_uri"
-           " FROM aggregation_transient atr"
-           " JOIN wire_targets wt USING (wire_target_h_payto)"
-           " WHERE atr.wire_target_h_payto=$1;");
+           "  atr.amount"
+           " ,atr.wtid_raw"
+           " ,atr.merchant_pub"
+           " ,wt.payto_uri"
+           " FROM wire_targets wt"
+           " JOIN aggregation_transient atr"
+           "   USING (wire_target_h_payto)"
+           " WHERE wt.h_normalized_payto=$1;");
   qs = GNUNET_PQ_eval_prepared_multi_select (pg->conn,
                                              "find_transient_aggregations",
                                              params,
