@@ -117,7 +117,8 @@ add_coin_deposit (void *cls,
         GNUNET_PQ_result_spec_auto_from_type ("wire_salt",
                                               &deposit->wire_salt),
         GNUNET_PQ_result_spec_string ("payto_uri",
-                                      &deposit->receiver_wire_account),
+                                      &deposit->receiver_wire_account.full_payto
+                                      ),
         GNUNET_PQ_result_spec_auto_from_type ("coin_sig",
                                               &deposit->csig),
         GNUNET_PQ_result_spec_uint64 ("coin_deposit_serial_id",
@@ -786,7 +787,7 @@ handle_history_entry (void *cls,
                   (int) qs,
                   (unsigned long long) serial_id,
                   table_name);
-      if (0 >= qs)
+      if (0 > qs)
         chc->failed = true;
       break;
     }
