@@ -30,7 +30,8 @@
 enum GNUNET_DB_QueryStatus
 TEH_PG_insert_aml_decision (
   void *cls,
-  const struct TALER_PaytoHashP *h_payto,
+  const struct TALER_FullPayto payto_uri,
+  const struct TALER_NormalizedPaytoHashP *h_payto,
   struct GNUNET_TIME_Timestamp decision_time,
   struct GNUNET_TIME_Timestamp expiration_time,
   const json_t *properties,
@@ -43,7 +44,8 @@ TEH_PG_insert_aml_decision (
   const struct TALER_AmlOfficerSignatureP *decider_sig,
   bool *invalid_officer,
   bool *unknown_account,
-  struct GNUNET_TIME_Timestamp *last_date)
+  struct GNUNET_TIME_Timestamp *last_date,
+  uint64_t *legitimization_measure_serial_id)
 {
   struct PostgresClosure *pg = cls;
   struct TALER_KycCompletedEventP rep = {
@@ -51,23 +53,30 @@ TEH_PG_insert_aml_decision (
     .header.type = htons (TALER_DBEVENT_EXCHANGE_KYC_COMPLETED),
     .h_payto = *h_payto
   };
+  struct TALER_FullPaytoHashP h_full_payto;
   char *notify_s
     = GNUNET_PQ_get_event_notify_channel (&rep.header);
   struct GNUNET_PQ_QueryParam params[] = {
+    NULL == payto_uri.full_payto
+      ? GNUNET_PQ_query_param_null ()
+      : GNUNET_PQ_query_param_string (payto_uri.full_payto),
     GNUNET_PQ_query_param_auto_from_type (h_payto),
+    NULL == payto_uri.full_payto
+      ? GNUNET_PQ_query_param_null ()
+      : GNUNET_PQ_query_param_auto_from_type (&h_full_payto),
     GNUNET_PQ_query_param_timestamp (&decision_time),
     GNUNET_PQ_query_param_timestamp (&expiration_time),
     NULL != properties
-    ? TALER_PQ_query_param_json (properties)
-    : GNUNET_PQ_query_param_null (),
+      ? TALER_PQ_query_param_json (properties)
+      : GNUNET_PQ_query_param_null (),
     TALER_PQ_query_param_json (new_rules),
     GNUNET_PQ_query_param_bool (to_investigate),
     NULL != new_measure_name
-    ? GNUNET_PQ_query_param_string (new_measure_name)
-    : GNUNET_PQ_query_param_null (),
+      ? GNUNET_PQ_query_param_string (new_measure_name)
+      : GNUNET_PQ_query_param_null (),
     NULL != jmeasures
-    ? TALER_PQ_query_param_json (jmeasures)
-    : GNUNET_PQ_query_param_null (),
+      ? TALER_PQ_query_param_json (jmeasures)
+      : GNUNET_PQ_query_param_null (),
     GNUNET_PQ_query_param_string (justification),
     GNUNET_PQ_query_param_auto_from_type (decider_pub),
     GNUNET_PQ_query_param_auto_from_type (decider_sig),
@@ -81,18 +90,24 @@ TEH_PG_insert_aml_decision (
                                 unknown_account),
     GNUNET_PQ_result_spec_timestamp ("out_last_date",
                                      last_date),
+    GNUNET_PQ_result_spec_uint64 ("out_legitimization_measure_serial_id",
+                                  legitimization_measure_serial_id),
     GNUNET_PQ_result_spec_end
   };
   enum GNUNET_DB_QueryStatus qs;
 
+  if (NULL != payto_uri.full_payto)
+    TALER_full_payto_hash (payto_uri,
+                           &h_full_payto);
   PREPARE (pg,
            "do_insert_aml_decision",
            "SELECT"
            " out_invalid_officer"
            ",out_account_unknown"
            ",out_last_date"
+           ",out_legitimization_measure_serial_id"
            " FROM exchange_do_insert_aml_decision"
-           "($1, $2, $3, $4, $5, $6, $7, $8, $9, $10, $11, $12);");
+           "($1, $2, $3, $4, $5, $6, $7, $8, $9, $10, $11, $12, $13, $14);");
   qs = GNUNET_PQ_eval_prepared_singleton_select (pg->conn,
                                                  "do_insert_aml_decision",
                                                  params,
