@@ -26,10 +26,11 @@
 #include "pg_helper.h"
 #include <gnunet/gnunet_pq_lib.h>
 
+
 enum GNUNET_DB_QueryStatus
 TEH_PG_insert_kyc_requirement_process (
   void *cls,
-  const struct TALER_PaytoHashP *h_payto,
+  const struct TALER_NormalizedPaytoHashP *h_payto,
   uint32_t measure_index,
   uint64_t legitimization_measure_serial_id,
   const char *provider_name,
