@@ -168,12 +168,14 @@ static enum GNUNET_DB_QueryStatus
 irbt_cb_table_wire_targets (struct PostgresClosure *pg,
                             const struct TALER_EXCHANGEDB_TableData *td)
 {
-  struct TALER_PaytoHashP payto_hash;
+  struct TALER_NormalizedPaytoHashP normalized_payto_hash;
+  struct TALER_FullPaytoHashP full_payto_hash;
   struct GNUNET_PQ_QueryParam params[] = {
     GNUNET_PQ_query_param_uint64 (&td->serial),
-    GNUNET_PQ_query_param_auto_from_type (&payto_hash),
+    GNUNET_PQ_query_param_auto_from_type (&full_payto_hash),
+    GNUNET_PQ_query_param_auto_from_type (&normalized_payto_hash),
     GNUNET_PQ_query_param_string (
-      td->details.wire_targets.payto_uri),
+      td->details.wire_targets.full_payto_uri.full_payto),
     GNUNET_PQ_query_param_auto_from_type (
       &td->details.wire_targets.access_token),
     td->details.wire_targets.no_account
@@ -183,19 +185,23 @@ irbt_cb_table_wire_targets (struct PostgresClosure *pg,
     GNUNET_PQ_query_param_end
   };
 
-  TALER_payto_hash (
-    td->details.wire_targets.payto_uri,
-    &payto_hash);
+  TALER_full_payto_hash (
+    td->details.wire_targets.full_payto_uri,
+    &full_payto_hash);
+  TALER_full_payto_normalize_and_hash (
+    td->details.wire_targets.full_payto_uri,
+    &normalized_payto_hash);
   PREPARE (pg,
            "insert_into_table_wire_targets",
            "INSERT INTO wire_targets"
            "(wire_target_serial_id"
            ",wire_target_h_payto"
+           ",h_normalized_payto"
            ",payto_uri"
            ",access_token"
            ",target_pub"
            ") VALUES "
-           "($1, $2, $3, $4, $5);");
+           "($1, $2, $3, $4, $5, $6);");
   return GNUNET_PQ_eval_prepared_non_select (pg->conn,
                                              "insert_into_table_wire_targets",
                                              params);
@@ -1782,7 +1788,7 @@ irbt_cb_table_close_requests (struct PostgresClosure *pg,
       pg->conn,
       &td->details.close_requests.close_fee),
     GNUNET_PQ_query_param_string (
-      td->details.close_requests.payto_uri),
+      td->details.close_requests.payto_uri.full_payto),
     GNUNET_PQ_query_param_end
   };
 
@@ -2019,7 +2025,7 @@ irbt_cb_table_profit_drains (struct PostgresClosure *pg,
     GNUNET_PQ_query_param_string (
       td->details.profit_drains.account_section),
     GNUNET_PQ_query_param_string (
-      td->details.profit_drains.payto_uri),
+      td->details.profit_drains.payto_uri.full_payto),
     GNUNET_PQ_query_param_timestamp (
       &td->details.profit_drains.trigger_date),
     TALER_PQ_query_param_amount (
