@@ -98,7 +98,7 @@ iterate_kyc_reference_cb (void *cls,
 enum GNUNET_DB_QueryStatus
 TEH_PG_iterate_kyc_reference (
   void *cls,
-  const struct TALER_PaytoHashP *h_payto,
+  const struct TALER_NormalizedPaytoHashP *h_payto,
   TALER_EXCHANGEDB_LegitimizationProcessCallback lpc,
   void *lpc_cls)
 {
