@@ -76,7 +76,7 @@ recoup_refresh_serial_helper_cb (void *cls,
     struct TALER_CoinSpendPublicKeyP old_coin_pub;
     struct TALER_CoinPublicInfo coin;
     struct TALER_CoinSpendSignatureP coin_sig;
-    union TALER_DenominationBlindingKeyP coin_blind;
+    union GNUNET_CRYPTO_BlindingSecretP coin_blind;
     struct TALER_DenominationPublicKey denom_pub;
     struct TALER_DenominationHashP old_denom_pub_hash;
     struct TALER_Amount amount;
@@ -161,8 +161,6 @@ TEH_PG_select_recoup_refresh_above_serial_id (
   };
   enum GNUNET_DB_QueryStatus qs;
 
-  /* Used in #postgres_select_recoup_refresh_above_serial_id() to obtain
-     recoup-refresh transactions */
   PREPARE (pg,
            "recoup_refresh_get_incr",
            "SELECT"
