@@ -657,6 +657,11 @@ struct TALER_BANK_CreditDetails
    */
   struct TALER_Amount amount;
 
+  /**
+   * Fee paid by the creditor.
+   */
+  struct TALER_Amount credit_fee;
+
   /**
    * Time of the the transfer
    */
