@@ -153,17 +153,22 @@ struct TALER_TESTING_Credentials
   /**
    * RFC 8905 URI of the exchange.
    */
-  char *exchange_payto;
+  struct TALER_FullPayto exchange_payto;
 
   /**
    * RFC 8905 URI of a user.
    */
-  char *user42_payto;
+  struct TALER_FullPayto user42_payto;
 
   /**
    * RFC 8905 URI of a user.
    */
-  char *user43_payto;
+  struct TALER_FullPayto user43_payto;
+
+  /**
+   * RFC 8905 URI of a user.
+   */
+  struct TALER_FullPayto user44_payto;
 };
 
 
@@ -200,12 +205,12 @@ TALER_TESTING_get_credentials (
  * Allocate and return a piece of wire-details.  Combines
  * a @a payto -URL and adds some salt to create the JSON.
  *
- * @param payto payto://-URL to encapsulate
+ * @param fpayto payto://-URL to encapsulate
  * @return JSON describing the account, including the
  *         payto://-URL of the account, must be manually decref'd
  */
 json_t *
-TALER_TESTING_make_wire_details (const char *payto);
+TALER_TESTING_make_wire_details (const struct TALER_FullPayto fpayto);
 
 
 /**
@@ -354,8 +359,9 @@ struct TALER_TESTING_Command
  * @return the command, if it is found, or NULL.
  */
 const struct TALER_TESTING_Command *
-TALER_TESTING_interpreter_lookup_command (struct TALER_TESTING_Interpreter *is,
-                                          const char *label);
+TALER_TESTING_interpreter_lookup_command (
+  struct TALER_TESTING_Interpreter *is,
+  const char *label);
 
 
 /**
@@ -366,8 +372,9 @@ TALER_TESTING_interpreter_lookup_command (struct TALER_TESTING_Interpreter *is,
  * @return the command, if it is found, or NULL.
  */
 const struct TALER_TESTING_Command *
-TALER_TESTING_interpreter_get_command (struct TALER_TESTING_Interpreter *is,
-                                       const char *name);
+TALER_TESTING_interpreter_get_command (
+  struct TALER_TESTING_Interpreter *is,
+  const char *name);
 
 
 /**
@@ -626,6 +633,19 @@ TALER_TESTING_cmd_set_var (const char *name,
                            struct TALER_TESTING_Command cmd);
 
 
+/**
+ * Update interpreter @a is variable state due to execution of @a cmd.
+ *
+ * @param[in,out] is interpreter to update
+ * @param[in,out] cmd command that we are executing and that
+ *   needs to be checked for side-effects on the variable state
+ */
+void
+TALER_TESTING_update_variables_ (
+  struct TALER_TESTING_Interpreter *is,
+  struct TALER_TESTING_Command *cmd);
+
+
 /**
  * Launch GNU Taler setup.
  *
@@ -727,6 +747,29 @@ TALER_TESTING_cmd_bank_credits (
   long long num_results);
 
 
+/**
+ * Make an account access token request CMD.
+ *
+ * @param label command label.
+ * @param auth login data to use
+ * @param account_name account name to request access token for
+ * @param scope requested token scope
+ * @param refreshable true if the token should be refreshable
+ * @param duration how long should the token be valid
+ * @param expected_http_status expected server response code
+ * @return the command.
+ */
+struct TALER_TESTING_Command
+TALER_TESTING_cmd_bank_account_token (
+  const char *label,
+  const struct TALER_BANK_AuthenticationData *auth,
+  const char *account_name,
+  enum TALER_BANK_TokenScope scope,
+  bool refreshable,
+  struct GNUNET_TIME_Relative duration,
+  unsigned int expected_http_status);
+
+
 /**
  * Make a debit "history" CMD.
  *
@@ -761,8 +804,8 @@ struct TALER_TESTING_Command
 TALER_TESTING_cmd_transfer (const char *label,
                             const char *amount,
                             const struct TALER_BANK_AuthenticationData *auth,
-                            const char *payto_debit_account,
-                            const char *payto_credit_account,
+                            const struct TALER_FullPayto payto_debit_account,
+                            const struct TALER_FullPayto payto_credit_account,
                             const struct TALER_WireTransferIdentifierRawP *wtid,
                             const char *exchange_base_url);
 
@@ -849,7 +892,7 @@ TALER_TESTING_cmd_admin_add_incoming (
   const char *label,
   const char *amount,
   const struct TALER_BANK_AuthenticationData *auth,
-  const char *payto_debit_account);
+  const struct TALER_FullPayto payto_debit_account);
 
 
 /**
@@ -869,7 +912,7 @@ TALER_TESTING_cmd_admin_add_kycauth (
   const char *label,
   const char *amount,
   const struct TALER_BANK_AuthenticationData *auth,
-  const char *payto_debit_account,
+  const struct TALER_FullPayto payto_debit_account,
   const char *account_ref);
 
 
@@ -893,7 +936,7 @@ TALER_TESTING_cmd_admin_add_incoming_with_ref (
   const char *label,
   const char *amount,
   const struct TALER_BANK_AuthenticationData *auth,
-  const char *payto_debit_account,
+  const struct TALER_FullPayto payto_debit_account,
   const char *ref,
   unsigned int http_status);
 
@@ -1283,10 +1326,11 @@ TALER_TESTING_cmd_reserve_poll_finish (const char *label,
  * @return the command.
  */
 struct TALER_TESTING_Command
-TALER_TESTING_cmd_reserve_history (const char *label,
-                                   const char *reserve_reference,
-                                   const char *expected_balance,
-                                   unsigned int expected_response_code);
+TALER_TESTING_cmd_reserve_history (
+  const char *label,
+  const char *reserve_reference,
+  const char *expected_balance,
+  unsigned int expected_response_code);
 
 
 /**
@@ -1299,10 +1343,11 @@ TALER_TESTING_cmd_reserve_history (const char *label,
  * @return the command.
  */
 struct TALER_TESTING_Command
-TALER_TESTING_cmd_coin_history (const char *label,
-                                const char *coin_reference,
-                                const char *expected_balance,
-                                unsigned int expected_response_code);
+TALER_TESTING_cmd_coin_history (
+  const char *label,
+  const char *coin_reference,
+  const char *expected_balance,
+  unsigned int expected_response_code);
 
 
 /**
@@ -1318,13 +1363,14 @@ TALER_TESTING_cmd_coin_history (const char *label,
  * @return the command.
  */
 struct TALER_TESTING_Command
-TALER_TESTING_cmd_reserve_open (const char *label,
-                                const char *reserve_reference,
-                                const char *reserve_pay,
-                                struct GNUNET_TIME_Relative expiration_time,
-                                uint32_t min_purses,
-                                unsigned int expected_response_code,
-                                ...);
+TALER_TESTING_cmd_reserve_open (
+  const char *label,
+  const char *reserve_reference,
+  const char *reserve_pay,
+  struct GNUNET_TIME_Relative expiration_time,
+  uint32_t min_purses,
+  unsigned int expected_response_code,
+  ...);
 
 
 /**
@@ -1337,10 +1383,11 @@ TALER_TESTING_cmd_reserve_open (const char *label,
  * @return the command.
  */
 struct TALER_TESTING_Command
-TALER_TESTING_cmd_reserve_get_attestable (const char *label,
-                                          const char *reserve_reference,
-                                          unsigned int expected_response_code,
-                                          ...);
+TALER_TESTING_cmd_reserve_get_attestable (
+  const char *label,
+  const char *reserve_reference,
+  unsigned int expected_response_code,
+  ...);
 
 
 /**
@@ -1353,10 +1400,11 @@ TALER_TESTING_cmd_reserve_get_attestable (const char *label,
  * @return the command.
  */
 struct TALER_TESTING_Command
-TALER_TESTING_cmd_reserve_attest (const char *label,
-                                  const char *reserve_reference,
-                                  unsigned int expected_response_code,
-                                  ...);
+TALER_TESTING_cmd_reserve_attest (
+  const char *label,
+  const char *reserve_reference,
+  unsigned int expected_response_code,
+  ...);
 
 
 /**
@@ -1369,10 +1417,11 @@ TALER_TESTING_cmd_reserve_attest (const char *label,
  * @return the command.
  */
 struct TALER_TESTING_Command
-TALER_TESTING_cmd_reserve_close (const char *label,
-                                 const char *reserve_reference,
-                                 const char *target_account,
-                                 unsigned int expected_response_code);
+TALER_TESTING_cmd_reserve_close (
+  const char *label,
+  const char *reserve_reference,
+  struct TALER_FullPayto target_account,
+  unsigned int expected_response_code);
 
 
 /**
@@ -1395,14 +1444,15 @@ TALER_TESTING_cmd_reserve_close (const char *label,
  * @return the command.
  */
 struct TALER_TESTING_Command
-TALER_TESTING_cmd_deposit (const char *label,
-                           const char *coin_reference,
-                           unsigned int coin_index,
-                           const char *target_account_payto,
-                           const char *contract_terms,
-                           struct GNUNET_TIME_Relative refund_deadline,
-                           const char *amount,
-                           unsigned int expected_response_code);
+TALER_TESTING_cmd_deposit (
+  const char *label,
+  const char *coin_reference,
+  unsigned int coin_index,
+  const struct TALER_FullPayto target_account_payto,
+  const char *contract_terms,
+  struct GNUNET_TIME_Relative refund_deadline,
+  const char *amount,
+  unsigned int expected_response_code);
 
 /**
  * Create a "deposit" command that references an existing merchant key.
@@ -1429,15 +1479,16 @@ TALER_TESTING_cmd_deposit (const char *label,
  * @return the command.
  */
 struct TALER_TESTING_Command
-TALER_TESTING_cmd_deposit_with_ref (const char *label,
-                                    const char *coin_reference,
-                                    unsigned int coin_index,
-                                    const char *target_account_payto,
-                                    const char *contract_terms,
-                                    struct GNUNET_TIME_Relative refund_deadline,
-                                    const char *amount,
-                                    unsigned int expected_response_code,
-                                    const char *merchant_priv_reference);
+TALER_TESTING_cmd_deposit_with_ref (
+  const char *label,
+  const char *coin_reference,
+  unsigned int coin_index,
+  const struct TALER_FullPayto target_account_payto,
+  const char *contract_terms,
+  struct GNUNET_TIME_Relative refund_deadline,
+  const char *amount,
+  unsigned int expected_response_code,
+  const char *merchant_priv_reference);
 
 /**
  * Modify a deposit command to enable retries when we get transient
@@ -1482,12 +1533,13 @@ TALER_TESTING_cmd_deposit_replay (const char *label,
  * @return the command.
  */
 struct TALER_TESTING_Command
-TALER_TESTING_cmd_batch_deposit (const char *label,
-                                 const char *target_account_payto,
-                                 const char *contract_terms,
-                                 struct GNUNET_TIME_Relative refund_deadline,
-                                 unsigned int expected_response_code,
-                                 ...);
+TALER_TESTING_cmd_batch_deposit (
+  const char *label,
+  const struct TALER_FullPayto target_account_payto,
+  const char *contract_terms,
+  struct GNUNET_TIME_Relative refund_deadline,
+  unsigned int expected_response_code,
+  ...);
 
 
 /**
@@ -1658,11 +1710,12 @@ TALER_TESTING_cmd_track_transfer (const char *label,
  * @return the command
  */
 struct TALER_TESTING_Command
-TALER_TESTING_cmd_check_bank_transfer (const char *label,
-                                       const char *exchange_base_url,
-                                       const char *amount,
-                                       const char *debit_payto,
-                                       const char *credit_payto);
+TALER_TESTING_cmd_check_bank_transfer (
+  const char *label,
+  const char *exchange_base_url,
+  const char *amount,
+  const struct TALER_FullPayto debit_payto,
+  const struct TALER_FullPayto credit_payto);
 
 
 /**
@@ -1677,11 +1730,12 @@ TALER_TESTING_cmd_check_bank_transfer (const char *label,
  * @return the command
  */
 struct TALER_TESTING_Command
-TALER_TESTING_cmd_check_bank_admin_transfer (const char *label,
-                                             const char *amount,
-                                             const char *debit_payto,
-                                             const char *credit_payto,
-                                             const char *reserve_pub_ref);
+TALER_TESTING_cmd_check_bank_admin_transfer (
+  const char *label,
+  const char *amount,
+  const struct TALER_FullPayto debit_payto,
+  const struct TALER_FullPayto credit_payto,
+  const char *reserve_pub_ref);
 
 
 /**
@@ -1696,8 +1750,9 @@ TALER_TESTING_cmd_check_bank_admin_transfer (const char *label,
  * @return the command.
  */
 struct TALER_TESTING_Command
-TALER_TESTING_cmd_check_bank_transfer_with_ref (const char *label,
-                                                const char *deposit_reference);
+TALER_TESTING_cmd_check_bank_transfer_with_ref (
+  const char *label,
+  const char *deposit_reference);
 
 
 /**
@@ -2057,7 +2112,7 @@ TALER_TESTING_cmd_set_wire_fee (const char *label,
  */
 struct TALER_TESTING_Command
 TALER_TESTING_cmd_wire_add (const char *label,
-                            const char *payto_uri,
+                            const struct TALER_FullPayto payto_uri,
                             unsigned int expected_http_status,
                             bool bad_sig);
 
@@ -2074,7 +2129,7 @@ TALER_TESTING_cmd_wire_add (const char *label,
  */
 struct TALER_TESTING_Command
 TALER_TESTING_cmd_wire_del (const char *label,
-                            const char *payto_uri,
+                            const struct TALER_FullPayto payto_uri,
                             unsigned int expected_http_status,
                             bool bad_sig);
 
@@ -2209,6 +2264,7 @@ TALER_TESTING_cmd_wallet_kyc_get (
  * @param label command label.
  * @param payment_target_reference command with a payment target to query
  * @param account_reference command with account private key to query
+ * @param lpt target for long polling
  * @param expected_response_code expected HTTP status
  * @return the command
  */
@@ -2217,6 +2273,7 @@ TALER_TESTING_cmd_check_kyc_get (
   const char *label,
   const char *payment_target_reference,
   const char *account_reference,
+  enum TALER_EXCHANGE_KycLongPollTarget lpt,
   unsigned int expected_response_code);
 
 
@@ -2722,6 +2779,7 @@ TALER_TESTING_get_trait (const struct TALER_TESTING_Trait *traits,
  */
 #define TALER_TESTING_SIMPLE_TRAITS(op) \
         op (bank_row, const uint64_t)                                    \
+        op (access_token, const char)                                    \
         op (officer_pub, const struct TALER_AmlOfficerPublicKeyP)        \
         op (officer_priv, const struct TALER_AmlOfficerPrivateKeyP)      \
         op (officer_name, const char)                                    \
@@ -2737,7 +2795,8 @@ TALER_TESTING_get_trait (const struct TALER_TESTING_Trait *traits,
         op (contract_priv, const struct TALER_ContractDiffiePrivateP)    \
         op (reserve_priv, const struct TALER_ReservePrivateKeyP)         \
         op (reserve_sig, const struct TALER_ReserveSignatureP)           \
-        op (h_payto, const struct TALER_PaytoHashP)                      \
+        op (h_full_payto, const struct TALER_FullPaytoHashP)             \
+        op (h_normalized_payto, const struct TALER_NormalizedPaytoHashP) \
         op (account_access_token, const struct TALER_AccountAccessTokenP) \
         op (account_priv, const union TALER_AccountPrivateKeyP)          \
         op (account_pub, const union TALER_AccountPublicKeyP)            \
@@ -2755,14 +2814,15 @@ TALER_TESTING_get_trait (const struct TALER_TESTING_Trait *traits,
         op (auditor_url, const char)                                     \
         op (exchange_bank_account_url, const char)                       \
         op (taler_uri, const char)                                       \
-        op (payto_uri, const char)                                       \
+        op (full_payto_uri, const struct TALER_FullPayto)                \
+        op (normalized_payto_uri, const struct TALER_NormalizedPayto)    \
         op (kyc_url, const char)                                         \
         op (web_url, const char)                                         \
         op (row, const uint64_t)                                         \
         op (legi_requirement_row, const uint64_t)                        \
         op (array_length, const unsigned int)                            \
-        op (credit_payto_uri, const char)                                \
-        op (debit_payto_uri, const char)                                 \
+        op (credit_payto_uri, const struct TALER_FullPayto)              \
+        op (debit_payto_uri, const struct TALER_FullPayto)               \
         op (order_id, const char)                                        \
         op (amount, const struct TALER_Amount)                           \
         op (amount_with_fee, const struct TALER_Amount)                  \
