@@ -22,6 +22,7 @@
 #include "taler_kyclogic_plugin.h"
 #include "taler_mhd_lib.h"
 #include "taler_templating_lib.h"
+#include "taler_curl_lib.h"
 #include "taler_json_lib.h"
 #include <regex.h>
 #include "taler_util.h"
@@ -142,7 +143,7 @@ struct TALER_KYCLOGIC_InitiateHandle
    * Hash of the payto:// URI we are initiating
    * the KYC for.
    */
-  struct TALER_PaytoHashP h_payto;
+  struct TALER_NormalizedPaytoHashP h_payto;
 
   /**
    * UUID being checked.
@@ -174,6 +175,17 @@ struct TALER_KYCLOGIC_InitiateHandle
    */
   void *cb_cls;
 
+  /**
+   * Initial address to pass to the KYC provider on /setup.
+   */
+  json_t *initial_address;
+
+  /**
+   * Context for #TEH_curl_easy_post(). Keeps the data that must
+   * persist for Curl to make the upload.
+   */
+  struct TALER_CURL_PostContext ctx;
+
 };
 
 
@@ -202,7 +214,7 @@ struct TALER_KYCLOGIC_ProofHandle
   /**
    * Hash of the payto URI that this is about.
    */
-  struct TALER_PaytoHashP h_payto;
+  struct TALER_NormalizedPaytoHashP h_payto;
 
   /**
    * Continuation to call.
@@ -532,6 +544,30 @@ oauth2_load_configuration (void *cls,
 }
 
 
+/**
+ * Cancel KYC check initiation.
+ *
+ * @param[in] ih handle of operation to cancel
+ */
+static void
+oauth2_initiate_cancel (struct TALER_KYCLOGIC_InitiateHandle *ih)
+{
+  if (NULL != ih->task)
+  {
+    GNUNET_SCHEDULER_cancel (ih->task);
+    ih->task = NULL;
+  }
+  if (NULL != ih->job)
+  {
+    GNUNET_CURL_job_cancel (ih->job);
+    ih->job = NULL;
+  }
+  TALER_curl_easy_post_finished (&ih->ctx);
+  json_decref (ih->initial_address);
+  GNUNET_free (ih);
+}
+
+
 /**
  * Logic to asynchronously return the response for
  * how to begin the OAuth2.0 checking process to
@@ -586,7 +622,7 @@ initiate_with_url (struct TALER_KYCLOGIC_InitiateHandle *ih,
           NULL /* no error */);
   GNUNET_free (url);
   GNUNET_free (hps);
-  GNUNET_free (ih);
+  oauth2_initiate_cancel (ih);
 }
 
 
@@ -620,7 +656,7 @@ handle_curl_setup_finished (void *cls,
             NULL,
             NULL,
             "/setup request to OAuth 2.0 backend returned no response");
-    GNUNET_free (ih);
+    oauth2_initiate_cancel (ih);
     return;
   case MHD_HTTP_OK:
     {
@@ -651,7 +687,7 @@ handle_curl_setup_finished (void *cls,
                 NULL,
                 NULL,
                 "Unexpected response from KYC gateway: setup must return a nonce");
-        GNUNET_free (ih);
+        oauth2_initiate_cancel (ih);
         return;
       }
       GNUNET_asprintf (&url,
@@ -674,7 +710,7 @@ handle_curl_setup_finished (void *cls,
             NULL,
             NULL,
             "/setup request to OAuth 2.0 backend returned unexpected HTTP status code");
-    GNUNET_free (ih);
+    oauth2_initiate_cancel (ih);
     return;
   }
 }
@@ -714,7 +750,7 @@ initiate_task (void *cls)
             NULL,
             NULL,
             "curl_easy_init() failed");
-    GNUNET_free (ih);
+    oauth2_initiate_cancel (ih);
     return;
   }
   GNUNET_assert (CURLE_OK ==
@@ -725,10 +761,31 @@ initiate_task (void *cls)
                  curl_easy_setopt (eh,
                                    CURLOPT_POST,
                                    1));
-  GNUNET_assert (CURLE_OK ==
-                 curl_easy_setopt (eh,
-                                   CURLOPT_POSTFIELDS,
-                                   ""));
+  if (NULL == ih->initial_address)
+  {
+    GNUNET_assert (CURLE_OK ==
+                   curl_easy_setopt (eh,
+                                     CURLOPT_POSTFIELDS,
+                                     ""));
+  }
+  else
+  {
+    if (GNUNET_OK !=
+        TALER_curl_easy_post (&ih->ctx,
+                              eh,
+                              ih->initial_address))
+    {
+      curl_easy_cleanup (eh);
+      ih->cb (ih->cb_cls,
+              TALER_EC_GENERIC_ALLOCATION_FAILURE,
+              NULL,
+              NULL,
+              NULL,
+              "TALER_curl_easy_post() failed");
+      oauth2_initiate_cancel (ih);
+      return;
+    }
+  }
   GNUNET_assert (CURLE_OK ==
                  curl_easy_setopt (eh,
                                    CURLOPT_FOLLOWLOCATION,
@@ -760,6 +817,7 @@ initiate_task (void *cls)
  * @param pd provider configuration details
  * @param account_id which account to trigger process for
  * @param legitimization_uuid unique ID for the legitimization process
+ * @param context additional contextual information for the legi process
  * @param cb function to call with the result
  * @param cb_cls closure for @a cb
  * @return handle to cancel operation early
@@ -767,8 +825,9 @@ initiate_task (void *cls)
 static struct TALER_KYCLOGIC_InitiateHandle *
 oauth2_initiate (void *cls,
                  const struct TALER_KYCLOGIC_ProviderDetails *pd,
-                 const struct TALER_PaytoHashP *account_id,
+                 const struct TALER_NormalizedPaytoHashP *account_id,
                  uint64_t legitimization_uuid,
+                 const json_t *context,
                  TALER_KYCLOGIC_InitiateCallback cb,
                  void *cb_cls)
 {
@@ -783,32 +842,13 @@ oauth2_initiate (void *cls,
   ih->pd = pd;
   ih->task = GNUNET_SCHEDULER_add_now (&initiate_task,
                                        ih);
+  if (NULL != context)
+    ih->initial_address = json_incref (json_object_get (context,
+                                                        "initial_address"));
   return ih;
 }
 
 
-/**
- * Cancel KYC check initiation.
- *
- * @param[in] ih handle of operation to cancel
- */
-static void
-oauth2_initiate_cancel (struct TALER_KYCLOGIC_InitiateHandle *ih)
-{
-  if (NULL != ih->task)
-  {
-    GNUNET_SCHEDULER_cancel (ih->task);
-    ih->task = NULL;
-  }
-  if (NULL != ih->job)
-  {
-    GNUNET_CURL_job_cancel (ih->job);
-    ih->job = NULL;
-  }
-  GNUNET_free (ih);
-}
-
-
 /**
  * Cancel KYC proof.
  *
@@ -859,6 +899,7 @@ return_proof_response (void *cls)
   ph->task = NULL;
   ph->cb (ph->cb_cls,
           ph->status,
+          ph->pd->section,
           ph->provider_user_id,
           ph->provider_legitimization_id,
           GNUNET_TIME_relative_to_absolute (ph->pd->validity),
@@ -1006,7 +1047,13 @@ converted_proof_cb (void *cls,
                                          ph);
     return;
   }
-
+  GNUNET_log (GNUNET_ERROR_TYPE_INFO,
+              "Attribute conversion output is:\n");
+  json_dumpf (attr,
+              stderr,
+              JSON_INDENT (2));
+  fprintf (stderr,
+           "\n");
   {
     const char *id;
     struct GNUNET_JSON_Specification ispec[] = {
@@ -1084,6 +1131,10 @@ parse_proof_success_reply (struct TALER_KYCLOGIC_ProofHandle *ph,
                            const json_t *j)
 {
   const struct TALER_KYCLOGIC_ProviderDetails *pd = ph->pd;
+  const char *argv[] = {
+    pd->conversion_binary,
+    NULL,
+  };
 
   GNUNET_log (GNUNET_ERROR_TYPE_INFO,
               "Calling converter `%s' with JSON\n",
@@ -1096,8 +1147,7 @@ parse_proof_success_reply (struct TALER_KYCLOGIC_ProofHandle *ph,
     &converted_proof_cb,
     ph,
     pd->conversion_binary,
-    pd->conversion_binary,
-    NULL);
+    argv);
   if (NULL != ph->ec)
     return;
   GNUNET_log (GNUNET_ERROR_TYPE_ERROR,
@@ -1398,7 +1448,7 @@ static struct TALER_KYCLOGIC_ProofHandle *
 oauth2_proof (void *cls,
               const struct TALER_KYCLOGIC_ProviderDetails *pd,
               struct MHD_Connection *connection,
-              const struct TALER_PaytoHashP *account_id,
+              const struct TALER_NormalizedPaytoHashP *account_id,
               uint64_t process_row,
               const char *provider_user_id,
               const char *provider_legitimization_id,
@@ -1696,6 +1746,10 @@ oauth2_webhook_cancel (struct TALER_KYCLOGIC_WebhookHandle *wh)
  * @return NULL on error, otherwise a `struct TALER_KYCLOGIC_Plugin`
  */
 void *
+libtaler_plugin_kyclogic_oauth2_init (void *cls);
+
+/* declaration to avoid compiler warning */
+void *
 libtaler_plugin_kyclogic_oauth2_init (void *cls)
 {
   const struct GNUNET_CONFIGURATION_Handle *cfg = cls;
@@ -1757,6 +1811,10 @@ libtaler_plugin_kyclogic_oauth2_init (void *cls)
  * @return NULL (always)
  */
 void *
+libtaler_plugin_kyclogic_oauth2_done (void *cls);
+
+/* declaration to avoid compiler warning */
+void *
 libtaler_plugin_kyclogic_oauth2_done (void *cls)
 {
   struct TALER_KYCLOGIC_Plugin *plugin = cls;
