@@ -144,7 +144,7 @@ struct TALER_KYCLOGIC_InitiateHandle
   /**
    * Hash of the payto:// URI we are initiating the KYC for.
    */
-  struct TALER_PaytoHashP h_payto;
+  struct TALER_NormalizedPaytoHashP h_payto;
 
   /**
    * UUID being checked.
@@ -245,7 +245,7 @@ struct TALER_KYCLOGIC_ProofHandle
   /**
    * Hash of the payto:// URI we are checking the KYC for.
    */
-  struct TALER_PaytoHashP h_payto;
+  struct TALER_NormalizedPaytoHashP h_payto;
 
   /**
    * Row in the legitimization processes of the
@@ -346,7 +346,7 @@ struct TALER_KYCLOGIC_WebhookHandle
   /**
    * Our account ID.
    */
-  struct TALER_PaytoHashP h_payto;
+  struct TALER_NormalizedPaytoHashP h_payto;
 
   /**
    * UUID being checked.
@@ -748,6 +748,7 @@ handle_initiate_finished (void *cls,
  * @param pd provider configuration details
  * @param account_id which account to trigger process for
  * @param legitimization_uuid unique ID for the legitimization process
+ * @param context additional contextual information for the legi process
  * @param cb function to call with the result
  * @param cb_cls closure for @a cb
  * @return handle to cancel operation early
@@ -755,8 +756,9 @@ handle_initiate_finished (void *cls,
 static struct TALER_KYCLOGIC_InitiateHandle *
 persona_initiate (void *cls,
                   const struct TALER_KYCLOGIC_ProviderDetails *pd,
-                  const struct TALER_PaytoHashP *account_id,
+                  const struct TALER_NormalizedPaytoHashP *account_id,
                   uint64_t legitimization_uuid,
+                  const json_t *context,
                   TALER_KYCLOGIC_InitiateCallback cb,
                   void *cb_cls)
 {
@@ -765,6 +767,7 @@ persona_initiate (void *cls,
   json_t *body;
   CURL *eh;
 
+  (void) context;
   eh = curl_easy_init ();
   if (NULL == eh)
   {
@@ -933,6 +936,7 @@ proof_generic_reply (struct TALER_KYCLOGIC_ProofHandle *ph,
   }
   ph->cb (ph->cb_cls,
           status,
+          ph->pd->section,
           account_id,
           inquiry_id,
           GNUNET_TIME_UNIT_ZERO_ABS,
@@ -1022,6 +1026,13 @@ start_conversion (const struct TALER_KYCLOGIC_ProviderDetails *pd,
                   TALER_JSON_JsonCallback cb,
                   void *cb_cls)
 {
+  const char *argv[] = {
+    pd->conversion_binary,
+    "-a",
+    pd->auth_token,
+    NULL,
+  };
+
   GNUNET_log (GNUNET_ERROR_TYPE_INFO,
               "Calling converter `%s' with JSON\n",
               pd->conversion_binary);
@@ -1033,11 +1044,7 @@ start_conversion (const struct TALER_KYCLOGIC_ProviderDetails *pd,
     cb,
     cb_cls,
     pd->conversion_binary,
-    pd->conversion_binary,
-    "-a",
-    pd->auth_token,
-    NULL
-    );
+    argv);
 }
 
 
@@ -1082,6 +1089,7 @@ proof_post_conversion_cb (void *cls,
   TALER_MHD_add_global_headers (resp);
   ph->cb (ph->cb_cls,
           TALER_KYCLOGIC_STATUS_SUCCESS,
+          ph->pd->section,
           ph->account_id,
           ph->inquiry_id,
           expiration,
@@ -1455,7 +1463,7 @@ static struct TALER_KYCLOGIC_ProofHandle *
 persona_proof (void *cls,
                const struct TALER_KYCLOGIC_ProviderDetails *pd,
                struct MHD_Connection *connection,
-               const struct TALER_PaytoHashP *account_id,
+               const struct TALER_NormalizedPaytoHashP *account_id,
                uint64_t process_row,
                const char *provider_user_id,
                const char *inquiry_id,
@@ -2169,6 +2177,10 @@ persona_webhook (void *cls,
  * @return NULL on error, otherwise a `struct TALER_KYCLOGIC_Plugin`
  */
 void *
+libtaler_plugin_kyclogic_persona_init (void *cls);
+
+/* declaration to avoid compiler warning */
+void *
 libtaler_plugin_kyclogic_persona_init (void *cls)
 {
   const struct GNUNET_CONFIGURATION_Handle *cfg = cls;
@@ -2239,6 +2251,11 @@ libtaler_plugin_kyclogic_persona_init (void *cls)
  * @param cls a `struct TALER_KYCLOGIC_Plugin`
  * @return NULL (always)
  */
+void *
+libtaler_plugin_kyclogic_persona_done (void *cls);
+
+/* declaration to avoid compiler warning */
+
 void *
 libtaler_plugin_kyclogic_persona_done (void *cls)
 {
