@@ -86,7 +86,7 @@ struct TALER_KYCLOGIC_InitiateHandle
    * Hash of the payto:// URI we are initiating
    * the KYC for.
    */
-  struct TALER_PaytoHashP h_payto;
+  struct TALER_NormalizedPaytoHashP h_payto;
 
   /**
    * UUID being checked.
@@ -235,6 +235,7 @@ template_initiate_cancel (struct TALER_KYCLOGIC_InitiateHandle *ih)
  * @param pd provider configuration details
  * @param account_id which account to trigger process for
  * @param legitimization_uuid unique ID for the legitimization process
+ * @param context additional contextual information for the legi process
  * @param cb function to call with the result
  * @param cb_cls closure for @a cb
  * @return handle to cancel operation early
@@ -242,14 +243,16 @@ template_initiate_cancel (struct TALER_KYCLOGIC_InitiateHandle *ih)
 static struct TALER_KYCLOGIC_InitiateHandle *
 template_initiate (void *cls,
                    const struct TALER_KYCLOGIC_ProviderDetails *pd,
-                   const struct TALER_PaytoHashP *account_id,
+                   const struct TALER_NormalizedPaytoHashP *account_id,
                    uint64_t legitimization_uuid,
+                   const json_t *context,
                    TALER_KYCLOGIC_InitiateCallback cb,
                    void *cb_cls)
 {
   struct TALER_KYCLOGIC_InitiateHandle *ih;
 
   (void) cls;
+  (void) context;
   ih = GNUNET_new (struct TALER_KYCLOGIC_InitiateHandle);
   ih->legitimization_uuid = legitimization_uuid;
   ih->cb = cb;
@@ -292,7 +295,7 @@ static struct TALER_KYCLOGIC_ProofHandle *
 template_proof (void *cls,
                 const struct TALER_KYCLOGIC_ProviderDetails *pd,
                 struct MHD_Connection *connection,
-                const struct TALER_PaytoHashP *account_id,
+                const struct TALER_NormalizedPaytoHashP *account_id,
                 uint64_t process_row,
                 const char *provider_user_id,
                 const char *provider_legitimization_id,
@@ -384,6 +387,10 @@ template_webhook (void *cls,
  * @return NULL on error, otherwise a `struct TALER_KYCLOGIC_Plugin`
  */
 void *
+libtaler_plugin_kyclogic_template_init (void *cls);
+
+/* declaration to avoid compiler warning */
+void *
 libtaler_plugin_kyclogic_template_init (void *cls)
 {
   const struct GNUNET_CONFIGURATION_Handle *cfg = cls;
@@ -446,6 +453,10 @@ libtaler_plugin_kyclogic_template_init (void *cls)
  * @return NULL (always)
  */
 void *
+libtaler_plugin_kyclogic_template_done (void *cls);
+
+/* declaration to avoid compiler warning */
+void *
 libtaler_plugin_kyclogic_template_done (void *cls)
 {
   struct TALER_KYCLOGIC_Plugin *plugin = cls;
