@@ -17,6 +17,7 @@
  * @file taler-exchange-kyc-tester.c
  * @brief tool to test KYC integrations
  * @author Christian Grothoff
+ * @defgroup request Request handling routines
  */
 #include "platform.h"
 #include <gnunet/gnunet_util_lib.h>
@@ -239,7 +240,7 @@ static char *TEKT_base_url;
 /**
  * Payto set via command-line (or otherwise random).
  */
-static struct TALER_PaytoHashP cmd_line_h_payto;
+static struct TALER_NormalizedPaytoHashP cmd_line_h_payto;
 
 /**
  * Provider user ID to use.
@@ -454,7 +455,7 @@ static void
 webhook_finished_cb (
   void *cls,
   uint64_t process_row,
-  const struct TALER_PaytoHashP *account_id,
+  const struct TALER_NormalizedPaytoHashP *account_id,
   const char *provider_section,
   const char *provider_user_id,
   const char *provider_legitimization_id,
@@ -565,7 +566,7 @@ kyc_provider_account_lookup (
   void *cls,
   const char *provider_section,
   const char *provider_legitimization_id,
-  struct TALER_PaytoHashP *h_payto,
+  struct TALER_NormalizedPaytoHashP *h_payto,
   uint64_t *legi_row)
 {
   (void) cls;
@@ -719,6 +720,7 @@ handler_kyc_webhook_post (
  *
  * @param cls closure with the `struct ProofRequestState`
  * @param status KYC status
+ * @param provider_name name of the KYC provider
  * @param provider_user_id set to user ID at the provider, or NULL if not supported or unknown
  * @param provider_legitimization_id set to legitimization process ID at the provider, or NULL if not supported or unknown
  * @param expiration until when is the KYC check valid
@@ -730,6 +732,7 @@ static void
 proof_cb (
   void *cls,
   enum TALER_KYCLOGIC_KycStatus status,
+  const char *provider_name,
   const char *provider_user_id,
   const char *provider_legitimization_id,
   struct GNUNET_TIME_Absolute expiration,
@@ -740,6 +743,7 @@ proof_cb (
   struct ProofRequestState *rs = cls;
 
   (void) expiration;
+  (void) provider_name;
   GNUNET_log (GNUNET_ERROR_TYPE_MESSAGE,
               "KYC legitimization %s completed with status %d (%u) for %s\n",
               provider_legitimization_id,
@@ -783,7 +787,7 @@ handler_kyc_proof_get (
   struct TEKT_RequestContext *rc,
   const char *const args[1])
 {
-  struct TALER_PaytoHashP h_payto;
+  struct TALER_NormalizedPaytoHashP h_payto;
   struct TALER_KYCLOGIC_ProviderDetails *pd;
   struct TALER_KYCLOGIC_Plugin *logic;
   struct ProofRequestState *rs;
@@ -1493,7 +1497,7 @@ run (void *cls,
   (void) args;
   (void ) cfgfile;
   if (GNUNET_OK !=
-      TALER_TEMPLATING_init ("exchange"))
+      TALER_TEMPLATING_init (TALER_EXCHANGE_project_data ()))
   {
     GNUNET_log (GNUNET_ERROR_TYPE_ERROR,
                 "Could not load templates. Installation broken.\n");
@@ -1686,6 +1690,7 @@ run (void *cls,
                                  pd,
                                  &cmd_line_h_payto,
                                  kyc_row_id,
+                                 NULL, /* FIXME: support passing context*/
                                  &initiate_cb,
                                  NULL);
         GNUNET_break (NULL != ih);
@@ -1748,11 +1753,12 @@ run (void *cls,
 
 
 /**
- * The main function of the taler-exchange-httpd server ("the exchange").
+ * The main function of the taler-exchange-kyc-tester, a tool for
+ * testing KYC processes.
  *
  * @param argc number of arguments from the command line
  * @param argv command line arguments
- * @return 0 ok, 1 on error
+ * @return 0 ok, non-zero on error
  */
 int
 main (int argc,
@@ -1760,6 +1766,7 @@ main (int argc,
 {
   const struct GNUNET_GETOPT_CommandLineOption options[] = {
     GNUNET_GETOPT_option_help (
+      TALER_EXCHANGE_project_data (),
       "tool to test KYC provider integrations"),
     GNUNET_GETOPT_option_flag (
       'M',
@@ -1781,7 +1788,7 @@ main (int argc,
     GNUNET_GETOPT_option_flag (
       'P',
       "print-payto-hash",
-      "output the hash of the payto://-URI",
+      "output the hash of the (normalized) payto://-URI",
       &print_h_payto),
     GNUNET_GETOPT_option_base32_fixed_size (
       'p',
@@ -1829,11 +1836,11 @@ main (int argc,
   };
   enum GNUNET_GenericReturnValue ret;
 
-  TALER_OS_init ();
   GNUNET_CRYPTO_random_block (GNUNET_CRYPTO_QUALITY_NONCE,
                               &cmd_line_h_payto,
                               sizeof (cmd_line_h_payto));
-  ret = GNUNET_PROGRAM_run (argc, argv,
+  ret = GNUNET_PROGRAM_run (TALER_EXCHANGE_project_data (),
+                            argc, argv,
                             "taler-exchange-kyc-tester",
                             "tool to test KYC provider integrations",
                             options,
