@@ -40,12 +40,12 @@
  * Which version of the Taler protocol is implemented
  * by this library?  Used to determine compatibility.
  */
-#define EXCHANGE_PROTOCOL_CURRENT 23
+#define EXCHANGE_PROTOCOL_CURRENT 24
 
 /**
  * How many versions are we backwards compatible with?
  */
-#define EXCHANGE_PROTOCOL_AGE 6
+#define EXCHANGE_PROTOCOL_AGE 5
 
 /**
  * Set to 1 for extra debug logging.
@@ -987,11 +987,9 @@ decode_keys_json (const json_t *resp_obj,
       GNUNET_JSON_spec_array_const (
         "auditors",
         &auditors_array),
-      GNUNET_JSON_spec_mark_optional (
-        GNUNET_JSON_spec_bool (
-          "rewards_allowed",
-          &key_data->rewards_allowed),
-        NULL),
+      GNUNET_JSON_spec_bool (
+        "kyc_enabled",
+        &key_data->kyc_enabled),
       GNUNET_JSON_spec_mark_optional (
         GNUNET_JSON_spec_object_const ("extensions",
                                        &manifests),
@@ -2628,8 +2626,8 @@ TALER_EXCHANGE_keys_to_json (const struct TALER_EXCHANGE_Keys *kd)
                                     recoup)),
     GNUNET_JSON_pack_array_steal ("auditors",
                                   auditors),
-    GNUNET_JSON_pack_bool ("rewards_allowed",
-                           kd->rewards_allowed),
+    GNUNET_JSON_pack_bool ("kyc_enabled",
+                           kd->kyc_enabled),
     GNUNET_JSON_pack_allow_null (
       GNUNET_JSON_pack_object_incref ("extensions",
                                       kd->extensions)),
