@@ -144,6 +144,7 @@ run (void *cls,
       "check-kyc-withdraw",
       "withdraw-coin-1-lacking-kyc",
       "setup-account-key-withdraw",
+      TALER_EXCHANGE_KLPT_KYC_AUTH_TRANSFER,
       MHD_HTTP_ACCEPTED),
     TALER_TESTING_cmd_get_kyc_info (
       "get-kyc-info-withdraw",
@@ -186,6 +187,31 @@ run (void *cls,
     TALER_TESTING_cmd_end ()
   };
   struct TALER_TESTING_Command spend[] = {
+    TALER_TESTING_cmd_set_var (
+      "account-priv",
+      TALER_TESTING_cmd_deposit (
+        "deposit-simple-fail-kyc",
+        "withdraw-coin-1",
+        0,
+        cred.user43_payto,
+        "{\"items\":[{\"name\":\"ice cream\",\"value\":1}]}",
+        GNUNET_TIME_UNIT_ZERO,
+        "EUR:5",
+        MHD_HTTP_UNAVAILABLE_FOR_LEGAL_REASONS)),
+    TALER_TESTING_cmd_admin_add_kycauth (
+      "kyc-auth-transfer",
+      "EUR:0.01",
+      &cred.ba,
+      cred.user42_payto,
+      "deposit-simple-fail-kyc"),
+    TALER_TESTING_cmd_admin_add_kycauth (
+      "kyc-auth-transfer",
+      "EUR:0.01",
+      &cred.ba,
+      cred.user43_payto,
+      "deposit-simple-fail-kyc"),
+    CMD_EXEC_WIREWATCH (
+      "import-kyc-account"),
     TALER_TESTING_cmd_deposit (
       "deposit-simple",
       "withdraw-coin-1",
@@ -226,6 +252,7 @@ run (void *cls,
       "check-kyc-deposit",
       "track-deposit-kyc-ready",
       "setup-account-key-deposit",
+      TALER_EXCHANGE_KLPT_KYC_AUTH_TRANSFER,
       MHD_HTTP_ACCEPTED),
     TALER_TESTING_cmd_get_kyc_info (
       "get-kyc-info-deposit",
@@ -256,6 +283,7 @@ run (void *cls,
       "check-kyc-deposit-again",
       "track-deposit-kyc-ready",
       "setup-account-key-deposit",
+      TALER_EXCHANGE_KLPT_KYC_AUTH_TRANSFER,
       MHD_HTTP_ACCEPTED),
     TALER_TESTING_cmd_get_kyc_info (
       "get-kyc-info-deposit-again",
@@ -295,6 +323,7 @@ run (void *cls,
       "check-kyc-wallet",
       "wallet-kyc-fail",
       "wallet-kyc-fail",
+      TALER_EXCHANGE_KLPT_KYC_AUTH_TRANSFER,
       MHD_HTTP_ACCEPTED),
     TALER_TESTING_cmd_get_kyc_info (
       "get-kyc-info-kyc-wallet",
@@ -315,6 +344,7 @@ run (void *cls,
       "wallet-kyc-check",
       "wallet-kyc-fail",
       "wallet-kyc-fail",
+      TALER_EXCHANGE_KLPT_KYC_AUTH_TRANSFER,
       MHD_HTTP_OK),
     TALER_TESTING_cmd_reserve_get_attestable (
       "wallet-get-attestable",
@@ -429,6 +459,7 @@ run (void *cls,
       "check-kyc-purse-merge",
       "purse-merge-into-reserve",
       "p2p_create-reserve-1",
+      TALER_EXCHANGE_KLPT_KYC_AUTH_TRANSFER,
       MHD_HTTP_ACCEPTED),
     TALER_TESTING_cmd_get_kyc_info (
       "get-kyc-info-purse-merge-into-reserve",
@@ -482,6 +513,7 @@ run (void *cls,
       "check-kyc-purse-create",
       "purse-create-with-reserve",
       "purse-create-with-reserve",
+      TALER_EXCHANGE_KLPT_KYC_AUTH_TRANSFER,
       MHD_HTTP_ACCEPTED),
     TALER_TESTING_cmd_get_kyc_info (
       "get-kyc-info-purse-create",
@@ -704,7 +736,7 @@ run (void *cls,
       "     ,\"verboten\":false"
       "   }"
       " ]" /* end new rules */
-      ",\"new_measure\":\"form-measure\""
+      ",\"new_measures\":\"form-measure\""
       ",\"custom_measures\":"
       "  {"
       "    \"form-measure\":"
@@ -722,6 +754,7 @@ run (void *cls,
       "check-kyc-form",
       "wallet-trigger-kyc-for-form-aml",
       "wallet-trigger-kyc-for-form-aml",
+      TALER_EXCHANGE_KLPT_KYC_AUTH_TRANSFER,
       MHD_HTTP_ACCEPTED),
     TALER_TESTING_cmd_get_kyc_info (
       "get-kyc-info-form",
