@@ -1,6 +1,6 @@
 /*
   This file is part of TALER
-  Copyright (C) 2018-2022 Taler Systems SA
+  Copyright (C) 2018-2024 Taler Systems SA
 
   TALER is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by
@@ -39,7 +39,7 @@
  * How long do we wait AT MOST when retrying?
  */
 #define MAX_BACKOFF GNUNET_TIME_relative_multiply ( \
-    GNUNET_TIME_UNIT_MILLISECONDS, 100)
+          GNUNET_TIME_UNIT_MILLISECONDS, 100)
 
 
 /**
@@ -133,7 +133,13 @@ struct BatchDepositState
    * Set (by the interpreter) to a fresh private key.  This
    * key will be used to sign the deposit request.
    */
-  struct TALER_MerchantPrivateKeyP merchant_priv;
+  union TALER_AccountPrivateKeyP account_priv;
+
+  /**
+   * Set (by the interpreter) to the public key
+   * corresponding to @e account_priv.
+   */
+  union TALER_AccountPublicKeyP account_pub;
 
   /**
    * Deposit handle while operation is running.
@@ -171,6 +177,18 @@ struct BatchDepositState
    */
   struct TALER_ExchangeSignatureP exchange_sig;
 
+  /**
+   * Set to the KYC requirement payto hash *if* the exchange replied with a
+   * request for KYC.
+   */
+  struct TALER_NormalizedPaytoHashP h_payto;
+
+  /**
+   * Set to the KYC requirement row *if* the exchange replied with
+   * a request for KYC.
+   */
+  uint64_t requirement_row;
+
   /**
    * Reference to previous deposit operation.
    * Only present if we're supposed to replay the previous deposit.
@@ -218,12 +236,21 @@ batch_deposit_cb (void *cls,
                                      ds->expected_response_code);
     return;
   }
-  if (MHD_HTTP_OK == dr->hr.http_status)
+  switch (dr->hr.http_status)
   {
+  case MHD_HTTP_OK:
     ds->deposit_succeeded = GNUNET_YES;
     ds->exchange_timestamp = dr->details.ok.deposit_timestamp;
     ds->exchange_pub = *dr->details.ok.exchange_pub;
     ds->exchange_sig = *dr->details.ok.exchange_sig;
+    break;
+  case MHD_HTTP_UNAVAILABLE_FOR_LEGAL_REASONS:
+    /* nothing to check */
+    ds->requirement_row
+      = dr->details.unavailable_for_legal_reasons.requirement_row;
+    ds->h_payto
+      = dr->details.unavailable_for_legal_reasons.h_payto;
+    break;
   }
   TALER_TESTING_interpreter_next (ds->is);
 }
@@ -243,16 +270,15 @@ batch_deposit_run (void *cls,
 {
   struct BatchDepositState *ds = cls;
   const struct TALER_DenominationSignature *denom_pub_sig;
-  struct TALER_MerchantPublicKeyP merchant_pub;
   struct TALER_PrivateContractHashP h_contract_terms;
   enum TALER_ErrorCode ec;
   struct TALER_WireSaltP wire_salt;
   struct TALER_MerchantWireHashP h_wire;
-  const char *payto_uri;
+  struct TALER_FullPayto payto_uri;
   struct TALER_EXCHANGE_CoinDepositDetail cdds[ds->num_coins];
   struct GNUNET_JSON_Specification spec[] = {
-    GNUNET_JSON_spec_string ("payto_uri",
-                             &payto_uri),
+    TALER_JSON_spec_full_payto_uri ("payto_uri",
+                                    &payto_uri),
     GNUNET_JSON_spec_fixed_auto ("salt",
                                  &wire_salt),
     GNUNET_JSON_spec_end ()
@@ -283,6 +309,13 @@ batch_deposit_run (void *cls,
     TALER_TESTING_interpreter_fail (is);
     return;
   }
+#if DUMP_CONTRACT
+  fprintf (stderr,
+           "Using contract:\n");
+  json_dumpf (ds->contract_terms,
+              stderr,
+              JSON_INDENT (2));
+#endif
   if (GNUNET_OK !=
       TALER_JSON_contract_hash (ds->contract_terms,
                                 &h_contract_terms))
@@ -311,9 +344,38 @@ batch_deposit_run (void *cls,
     ds->refund_deadline = ds->wallet_timestamp;
     ds->wire_deadline = GNUNET_TIME_timestamp_get ();
   }
-  GNUNET_CRYPTO_eddsa_key_get_public (&ds->merchant_priv.eddsa_priv,
-                                      &merchant_pub.eddsa_pub);
 
+  {
+    const struct TALER_TESTING_Command *acc_var;
+    if (NULL != (acc_var
+                   = TALER_TESTING_interpreter_get_command (
+                       is,
+                       "account-priv")))
+    {
+      const union TALER_AccountPrivateKeyP *account_priv;
+
+      if ( (GNUNET_OK !=
+            TALER_TESTING_get_trait_account_priv (acc_var,
+                                                  &account_priv)) )
+      {
+        GNUNET_break (0);
+        TALER_TESTING_interpreter_fail (is);
+        return;
+      }
+      ds->account_priv = *account_priv;
+      GNUNET_CRYPTO_eddsa_key_get_public (
+        &ds->account_priv.merchant_priv.eddsa_priv,
+        &ds->account_pub.merchant_pub.eddsa_pub);
+    }
+    else
+    {
+      GNUNET_CRYPTO_eddsa_key_create (
+        &ds->account_priv.merchant_priv.eddsa_priv);
+      GNUNET_CRYPTO_eddsa_key_get_public (
+        &ds->account_priv.merchant_priv.eddsa_priv,
+        &ds->account_pub.merchant_pub.eddsa_pub);
+    }
+  }
   for (unsigned int i = 0; i<ds->num_coins; i++)
   {
     struct Coin *coin = &ds->coins[i];
@@ -374,7 +436,7 @@ batch_deposit_run (void *cls,
                                NULL, /* hash of extensions */
                                &coin->denom_pub->h_key,
                                ds->wallet_timestamp,
-                               &merchant_pub,
+                               &ds->account_pub.merchant_pub,
                                ds->refund_deadline,
                                coin_priv,
                                &cdd->coin_sig);
@@ -386,7 +448,7 @@ batch_deposit_run (void *cls,
     coin->che.details.deposit.no_h_policy = true;
     coin->che.details.deposit.no_wallet_data_hash = true;
     coin->che.details.deposit.wallet_timestamp = ds->wallet_timestamp;
-    coin->che.details.deposit.merchant_pub = merchant_pub;
+    coin->che.details.deposit.merchant_pub = ds->account_pub.merchant_pub;
     coin->che.details.deposit.refund_deadline = ds->refund_deadline;
     coin->che.details.deposit.sig = cdd->coin_sig;
     coin->che.details.deposit.no_hac = GNUNET_is_zero (&cdd->h_age_commitment);
@@ -403,7 +465,7 @@ batch_deposit_run (void *cls,
       .h_contract_terms = h_contract_terms,
       .policy_details = NULL /* FIXME #7270-OEC */,
       .wallet_timestamp = ds->wallet_timestamp,
-      .merchant_pub = merchant_pub,
+      .merchant_pub = ds->account_pub.merchant_pub,
       .refund_deadline = ds->refund_deadline
     };
 
@@ -525,7 +587,10 @@ batch_deposit_traits (void *cls,
       /* These traits are always available */
       TALER_TESTING_make_trait_wire_details (ds->wire_details),
       TALER_TESTING_make_trait_contract_terms (ds->contract_terms),
-      TALER_TESTING_make_trait_merchant_priv (&ds->merchant_priv),
+      TALER_TESTING_make_trait_merchant_priv (&ds->account_priv.merchant_priv),
+      TALER_TESTING_make_trait_merchant_pub (&ds->account_pub.merchant_pub),
+      TALER_TESTING_make_trait_account_priv (&ds->account_priv),
+      TALER_TESTING_make_trait_account_pub (&ds->account_pub),
       TALER_TESTING_make_trait_age_commitment_proof (index,
                                                      age_commitment_proof),
       TALER_TESTING_make_trait_coin_history (index,
@@ -548,6 +613,8 @@ batch_deposit_traits (void *cls,
                                               &ds->wire_deadline),
       TALER_TESTING_make_trait_refund_deadline (index,
                                                 &ds->refund_deadline),
+      TALER_TESTING_make_trait_legi_requirement_row (&ds->requirement_row),
+      TALER_TESTING_make_trait_h_normalized_payto (&ds->h_payto),
       TALER_TESTING_trait_end ()
     };
 
@@ -562,12 +629,13 @@ batch_deposit_traits (void *cls,
 
 
 struct TALER_TESTING_Command
-TALER_TESTING_cmd_batch_deposit (const char *label,
-                                 const char *target_account_payto,
-                                 const char *contract_terms,
-                                 struct GNUNET_TIME_Relative refund_deadline,
-                                 unsigned int expected_response_code,
-                                 ...)
+TALER_TESTING_cmd_batch_deposit (
+  const char *label,
+  const struct TALER_FullPayto target_account_payto,
+  const char *contract_terms,
+  struct GNUNET_TIME_Relative refund_deadline,
+  unsigned int expected_response_code,
+  ...)
 {
   struct BatchDepositState *ds;
   va_list ap;
@@ -614,7 +682,6 @@ TALER_TESTING_cmd_batch_deposit (const char *label,
   ds->contract_terms = json_loads (contract_terms,
                                    JSON_REJECT_DUPLICATES,
                                    NULL);
-  GNUNET_CRYPTO_eddsa_key_create (&ds->merchant_priv.eddsa_priv);
   if (NULL == ds->contract_terms)
   {
     GNUNET_log (GNUNET_ERROR_TYPE_ERROR,
